#!/usr/bin/wish
#
# engarde2html - version 1.1.1
#
# Copyright 2006, Tony Aiuto
#
# Author: Tony Aiuto, tony.aiuto@gmail.com
#
# Usage:
#
# usage: engarde2html				-- for GUI
# usage: engarde2html [competition folder] ...
# usage: engarde2html .				-- for standard output
#

set VERSION 1.1.4


##############################################
#
# Local overrides to standard options
#

#
# If you really want, you may change some parameters here.
# The preferred method, however, is to create a file  local_custom.tcl
# and place it in the folder with this program.   That may include
# changes to the settings below.     New distributions of engarde2html
# will never overrwrite local_custom.tcl
#


#
#  HTML output variables
#

# Set this to 1 if you want to merge the CSS  file into the HTML output.
set INCLUDE_CSS_FILE 1

#
# name of file containing styles [default styles.css]
#
set CSS_FILE_NAME "styles.css"

#
# Extension for generated files.  Other popular choices are shtml and htm
#
set HTML_extension html


#
# Server to upload generated files to
#
set UPLOAD_SERVER "http://gw.aiu.to"
set UPLOAD_DIR results

#
# End of HTML settings
#


#
# FixupThisComp gets called *AFTER* the competition has been loaded
# but before any output gets done.
# This hook is provided as pure hackery to set some things that should
# be picked up from the command line or from the competition data itself.
# If you feel you must use this feature, then you should probably contact
# the author to figure out ways to avoid it.
#

proc FixupThisComp {} {
	global Competition

	# if it is a combined Div 2/3 qualifier, we have to turn this on
	# most other qualifiers get picked up from the competition name

 	# set Competition(isQualifier) d23
}


#
# End - Local overrides to standard options
#
##############################################



set prog $argv0
set progpath "."
regexp {^(.*)/[^/]*$} $prog junk progpath

#puts "argv0 = $argv0"
#puts "progpath = $progpath"

if { $progpath == "" || $progpath == "." } {
    set progpath [pwd]
}

# Load local customizations
# The _UNDER_RTEST hack is something to prevent this load if running
# under the regression test tool that I use.
if { ! [info exists env(_UNDER_RTEST_)] } {
    set localizationCommands [file join $progpath "local_custom.tcl"]
    if { [file exists $localizationCommands] } {
	source $localizationCommands
    }
}

source $progpath/fencing_util.tcl
source $progpath/fencing_usfa.tcl
source $progpath/engarde_load.tcl
source $progpath/fencing_data.tcl
source $progpath/print_html.tcl
source $progpath/print_PS.tcl
source $progpath/fencing_print_comp.tcl
source $progpath/scoresheets.tcl
source $progpath/send_files.tcl
source $progpath/fencing_fred.tcl


################################################################


#
# Print rankings at the end of a round of pools
#

proc PrintEndOfRound_text { out round _data title } {
  upvar $_data data
  if { "$title" != "" } {
    puts $out "=== $title ==="
  } else {
    puts $out "=== Ranking after this round of pools ==="
  }
  foreach fi [lsort -integer [array names $_data]] {
	array set fd $data($fi)

	puts $out "$fd(rank)|[FencerName $fd(fnumber)]|[FencerClub $fd(fnumber)]|$fd(wins)/$fd(bouts)|[format {%.3f} [expr 1.0 * $fd(wins) / $fd(bouts)]]|$fd(ts)|$fd(tr)|[expr $fd(ts) - $fd(tr)]"
  }
}

proc _compareRank { a b } {
   array set fd $data($fi)
}


proc PrintEndOfRound_HTML { out round _data title } {
  global RoundInfo Fencer

  upvar $_data data
  if { "$title" != "" } {
    puts $out "<p class=\"result_section\">$title</p>"
  }

    # get general information about the round
    array set rdata $RoundInfo($round)
    if { $rdata(fencers_in) != $rdata(fencers_out) } {
    	puts $out "$rdata(fencers_in) fencers, $rdata(fencers_out) promoted."
    }

    # provide an index
    puts $out {<table border="0"><tr><td>}

  puts $out {<table class="fencer_list" cellspacing="0">}
  puts $out {<caption>By rank</caption>}
  puts $out "<tr>"
  puts -nonewline $out "<th>Rank</th>"
  puts -nonewline $out "<th width=\"250\">Name</th>"
  puts -nonewline $out "<th>Club</th>"
  puts -nonewline $out "<th>Wins/Bouts</th>"
  puts -nonewline $out "<th>Pct.</th>"
  puts -nonewline $out "<th>TS</th>"
  puts -nonewline $out "<th>TR</th>"
  puts -nonewline $out "<th>Ind.</th>"
  puts $out "</tr>"
  foreach fi [lsort -integer [array names $_data]] {
	array set fd $data($fi)

        array set x $Fencer($fd(fnumber))

        set rankCSSClass "pr"
	if { $x(pool_status) != "q" } {
        	set rankCSSClass "ex"
	}
	puts -nonewline $out "<tr class=\"$rankCSSClass\">"
	puts -nonewline $out "<td class=\"index\">$fd(rank)</td>"
	puts -nonewline $out "<td>[FencerName $fd(fnumber)]</td>"
	puts -nonewline $out "<td>[FencerClub $fd(fnumber)]</td>"
	puts -nonewline $out "<td class=\"numb\">$fd(wins)/$fd(bouts)</td>"
	if { $x(pool_status) != "a" } {
		puts -nonewline $out "<td class=\"numb\">[format {%.3f} [expr 1.0 * $fd(wins) / $fd(bouts)]]</td>"
		puts -nonewline $out "<td class=\"numb\">$fd(ts)</td>"
		puts -nonewline $out "<td class=\"numb\">$fd(tr)</td>"
		puts -nonewline $out "<td class=\"numb\">[expr $fd(ts) - $fd(tr)]</td>"
	} else {
		puts -nonewline $out "<td class=\"numb\">--</td>"
		puts -nonewline $out "<td class=\"numb\">--</td>"
		puts -nonewline $out "<td class=\"numb\">--</td>"
		puts -nonewline $out "<td class=\"numb\">--</td>"
	}
	puts $out "</tr>"
  }
  puts $out "</table>"

  # provide an index
    puts $out {</td><td width="25"></td><td>}
    PrintRanksByName_HTML $out
    puts $out {</td></tr></table>}
}


proc PrintRanksByName_HTML { out } {
  global Fencer

  puts $out {<table class="fencer_list" cellspacing="0">}
  puts $out {<caption>By name</caption>}
  puts -nonewline $out {<tr>}
  puts -nonewline $out {<th colspan="1" width=\"200\">Fencer</th>}
  puts -nonewline $out {<th>&nbsp;Rank&nbsp;</th>}
  puts -nonewline $out {<th>Pct.</th>}
  puts -nonewline $out {<th>Ind.</th>}
  puts $out {</tr>}
  set pos 0
  foreach i [FencersByName] {
        array set x $Fencer($i)
        incr pos

	if { $x(isPresent) == 0 } continue

        puts -nonewline $out {<tr>}
        puts -nonewline $out "<td>$x(last_name), $x(first_name)</td>"
	if { [info exists x(pool_rank) ] && $x(pool_bouts) > 0 } {
          puts -nonewline $out "<td class=\"index\">$x(pool_rank)</td>"
	  set pct [expr 1.0 * $x(pool_wins) / $x(pool_bouts)]
	  puts -nonewline $out "<td class=\"numb\">[format {%.3f} $pct]</td>"
	  set ind [expr $x(pool_ts) - $x(pool_tr)]
          puts -nonewline $out "<td class=\"numb\">$ind</td>"
	} else {
	  puts -nonewline $out "<td>--<td>"
	  puts -nonewline $out "<td>--<td>"
	  puts -nonewline $out "<td>--<td>"
	}
        puts $out {</tr>}
  }
  puts $out {</table>}
}


proc PrintEndOfRound { out round _data title } {
  global PrintStyle
  upvar $_data data
  if { [ info proc "PrintEndOfRound_$PrintStyle" ] != "" } {
	PrintEndOfRound_$PrintStyle $out $round data $title
  } else {
	PrintEndOfRound_text $out $round data $title
  }
}




proc PrintRoundInfo { round } {
  global tour_de_poules PrintStyle

  puts "=== Pool Info ==="
  array set x $tour_de_poules($round)

  lineBreak_$PrintStyle
  puts "$x(nombre_poules) pools"
  lineBreak_$PrintStyle
  puts "$x(entites_exemptees) exemptions"
  lineBreak_$PrintStyle
  puts "$x(entites_par_poule) fencers / pool"
  lineBreak_$PrintStyle
  puts "$x(nombre_touches_poules) touches per bout"

  lineBreak_$PrintStyle
  puts "$x(qualifies_par_poule) quaifiers / pool"
  lineBreak_$PrintStyle
  puts "$x(qualifies_indice) qualifies_indice"
  lineBreak_$PrintStyle
  puts "$x(qualifies) qualify"
  lineBreak_$PrintStyle
  puts "$x(entites_fin) fencers at end of pools"
  
  lineBreak_$PrintStyle
  puts "entities_depart: $x(entites_depart)"
  lineBreak_$PrintStyle
  puts "$x(entites_dans_poules) fencers"
  lineBreak_$PrintStyle
  puts "critere_decal_1: $x(critere_decal_1)"
  
  lineBreak_$PrintStyle
  puts "critere_placement: $x(critere_placement)"
  lineBreak_$PrintStyle
  puts "seed by $x(critere)"
}




proc Pool_Print { out round pi } {
  global Pool
  array set p $Pool($pi)

  #DBG puts "Printing Round $round, Pool $pi"
  # parray p

  if { [ info exists p(piste_no) ] } {
    puts $out "Strip: $p(piste_no)"
  }

  if { ! [ info exists p(scores) ] } {
    set flist $p(les_tir_feuille)
    foreach fi $flist {
      puts -nonewline $out "[format {%2s } $fi]"
      puts $out "[format {%-25.25s} [FencerName $fi]]"
    }
    return
  }

  puts "tir_cons = $p(les_tir_cons)"
  #DBG puts "tir_fueille = $p(les_tir_feuille)"

  # reorganize the scores data by fencer
  # [scores ((e 7 17 6 1 16 29) (e 1 15 6 5 29 15) (e 3 20 6 3 24 22) ....
  foreach s $p(scores) {
     set rank [lindex $s 1]
     set fencerIndex [lindex $s 2]
     set bouts [lindex $s 3]
     set wins [lindex $s 4]
     set ts [lindex $s 5]
     set tr [lindex $s 6]
     set scores($fencerIndex) [list $rank $bouts $wins $ts $tr]
     #DBG puts "$fencerIndex: $s"
  }
 
  # print the fencers
  set flist $p(les_tir_feuille)
  set gi 0
  foreach fi $flist {
     puts -nonewline "[format {%2s } $fi]"
     puts -nonewline "[format {%-25.25s} [FencerName $fi]]"

     # {*** {}} {d 1} {v 5} {d 1} {d 4} {d 3} {d 2}
     set boutsForThisFencer [lindex $p(grille) $gi]
     incr gi

     set rank [lindex $scores($fi) 0]
     set bouts [lindex $scores($fi) 1]
     set wins [lindex $scores($fi) 2]
     set total_ts [lindex $scores($fi) 3]
     set total_tr [lindex $scores($fi) 4]

     foreach bout $boutsForThisFencer {
       set x [lindex $bout 0]
       set ts [lindex $bout 1]
       if { $x == "***" } {
         puts -nonewline " X "
       } elseif { $x == "v" } {
         puts -nonewline " V "
       } else {
         puts -nonewline " $ts "
       }
     }
     set ind [expr $total_ts - $total_tr]
     puts "    $wins/$bouts  [format {%2d %2d  %3d} $total_ts $total_tr $ind ] $rank"
  }
}


proc Pool_Print_HTML { out round pi } {
  global Pool
  array set p $Pool($pi)

  #DBG puts "Printing Round $round, Pool $pi"
  # parray p

  puts $out "<p class=\"result_section\">Round $round, Pool $pi</p>"
  if { [ info exists p(piste_no) ] } {
    puts $out "Strip: $p(piste_no)"
  }

  # the list of fencers is in pool order
  set flist $p(les_tir_feuille)

  # puts $out "tir_cons = $p(les_tir_cons)"
  set nBouts [llength $p(les_tir_cons)]

  # reorganize the scores data by fencer
  if { ! [ info exists p(scores) ] } {
    foreach fi $flist {
       set rank ""
       set fencerIndex $fi
       set bouts 0
       set wins 0
       set ts  ""
       set tr  ""
       set scores($fencerIndex) [list $rank $bouts $wins $ts $tr]
       #DBG puts $out "$fencerIndex: $s"
    }
  } else {
    # [scores ((e 7 17 6 1 16 29) (e 1 15 6 5 29 15) (e 3 20 6 3 24 22) ....
    foreach s $p(scores) {
       set rank [lindex $s 1]
       set fencerIndex [lindex $s 2]
       set bouts [lindex $s 3]
       set wins [lindex $s 4]
       set ts [lindex $s 5]
       set tr [lindex $s 6]
       set scores($fencerIndex) [list $rank $bouts $wins $ts $tr]
       #DBG puts $out "$fencerIndex: $s"
    }
  }
 
  # print the fencers
  puts $out {<table class="fencer_list" cellspacing="0" border="1">}
  puts -nonewline $out {<tr height="25">}
  puts -nonewline $out "<th id=\"index\">#</th>"
  puts -nonewline $out "<th width=\"250\">Fencer</th>"
  # puts -nonewline $out "<th width=\"70\">Club</th>"
  puts -nonewline $out "<th colspan=\"$nBouts\">Bouts</th>"
  puts -nonewline $out "<th>wins/bouts</th>"
  puts -nonewline $out "<th>TS</th>"
  puts -nonewline $out "<th>TR</th>"
  puts -nonewline $out "<th>Ind.</th>"
  puts -nonewline $out "<th>Rank</th>"
  puts -nonewline $out {</tr>}
  set flist $p(les_tir_feuille)
  set gi 0
  foreach fi $flist {

     # get the bout list for this fencer
     if { [info exists p(grille)] } {
       # {*** {}} {d 1} {v 5} {d 1} {d 4} {d 3} {d 2}
       set boutsForThisFencer [lindex $p(grille) $gi]
     } else {
       set boutsForThisFencer {}
       for { set i 0 } { $i < $nBouts } { incr i } {
         if { $i == $gi } {
           lappend boutsForThisFencer [list "***" x]
         } else {
           lappend boutsForThisFencer [list x x]
         }
       }
     }
     incr gi

     set rank [lindex $scores($fi) 0]
     set bouts [lindex $scores($fi) 1]
     set wins [lindex $scores($fi) 2]
     set total_ts [lindex $scores($fi) 3]
     set total_tr [lindex $scores($fi) 4]

     puts -nonewline $out {<tr class="gridrow">}
     # puts -nonewline $out "<td>[format {%2d} $fi]</td>"
     puts -nonewline $out "<td class=\"index\">[format {%2d} $gi]</td>"
     puts -nonewline $out "<td>[FencerName $fi]</td>"
     # puts -nonewline $out "<td>[FencerClub $fi]</td>"

     foreach bout $boutsForThisFencer {
       set x [lindex $bout 0]
       set ts [lindex $bout 1]
       puts -nonewline $out "<td width=\"25\" "
       if { $x == "***" } {
         puts -nonewline $out " class=\"gridblack\">&nbsp;"
       } elseif { $x == "v" } {
         puts -nonewline $out " class=\"gridcell\"> V "
       } elseif { $x == "w" } {
         puts -nonewline $out " class=\"gridcell\"> V$ts "
       } elseif { $x == "x" } {
         puts -nonewline $out " class=\"gridcell\">&nbsp;"
       } else {
         puts -nonewline $out " class=\"gridcell\"> $ts "
       }
       puts -nonewline $out {</td>}
     }
     if { $total_ts == "" } {
       set total_ts "&nbsp;"
       set total_tr "&nbsp;"
       set ind "&nbsp;"
       set rank "&nbsp;"
     } else {
       set ind [expr $total_ts - $total_tr]
     }
     if { $bouts == 0 } {
       puts -nonewline $out "<td class=\"numb\">&nbsp;</td>"
     } else {
       puts -nonewline $out "<td class=\"numb\">$wins/$bouts</td>"
     }
     puts -nonewline $out "<td class=\"numb\">$total_ts</td>"
     puts -nonewline $out "<td class=\"numb\">$total_tr</td>"
     puts -nonewline $out "<td class=\"numb\">$ind</td>"
     puts -nonewline $out "<td class=\"numb\">$rank</td>"
     puts $out {</tr>}
  }
  puts $out {</table>}
}



# 
# DealWithRound - load and print the data for a given round of pools
#

proc DealWithRound { out round } {
	global tour_de_poules PrintStyle

	# PrintRoundInfo $round

        set title "Rankings before round $round"
        if { $round == 1 } {
          set title "Rankings before pools"
        }
	if { [info procs PrintFencers_$PrintStyle] != "" } {
		PrintFencers_$PrintStyle $out $round $title
	}


        if { $round == 1 } {
	  puts $out "<hr/>"
	}
	# load and print the individual pools
	array set PoolInfo $tour_de_poules($round)
	for { set pool 1 } { $pool <= $PoolInfo(nombre_poules) } { incr pool } {
		global Pool

		# puts "Call Pool_LoadData $round $pool"

		# puts $Pool($pool)
		if { [info procs Pool_Print_$PrintStyle] != "" } {
			Pool_Print_$PrintStyle $out $round $pool
		} else {
			Pool_Print $out $round $pool
		}
	}
}





proc PrintDETableIndex_HTML { out } {
  global Competition Fencer Co

  if { $Competition(nFencers) <= 16 } { return }

  puts $out {<p class="result_section">Where are you in the DE tables?</p>}
  puts $out {<table class="fencer_list" cellspacing="0">}
  puts -nonewline $out {<tr>}
  puts -nonewline $out {<th colspan="1" width=\"250\">Fencer</th>}
  puts -nonewline $out {<th>Seed</th>}
  puts -nonewline $out {<th>DE quadrant<br/>page</th>}
  puts -nonewline $out {<th>Row on<br/>quadrant page</th>}
  puts $out {</tr>}
  # set pos 0
  foreach i [FencersByName] {
	array set x $Fencer($i)
	# incr pos
	if { $x(isPresent) == 0 } continue

  	puts -nonewline $out {<tr>}
     	puts -nonewline $out "<td>$x(last_name), $x(first_name)</td>"
     	puts -nonewline $out "<td class=\"index\">$x(seed)</td>"
	set deindex $x(tableIndex)
     	puts -nonewline $out "<td class=\"index\">[lindex $deindex 0]</td>"
     	puts -nonewline $out "<td class=\"index\">[lindex $deindex 1]</td>"
  	puts $out {</tr>}
  }
  puts $out {</table>}
}


#######################################################
#
# routines for tableaux printing
#
#

proc lfind { list tag } {
  foreach e $list {
    if { [lindex $e 0] == $tag } {
      return [lindex $e 1]
    }
  }
  return ""
}


proc putFencer { fi seed } {
  puts -nonewline "[format {%2d } $seed]"
  if { $fi == "nobody" } {
    puts -nonewline "   "
    puts -nonewline "                         "
  } else {
    puts -nonewline "[format {%2s } $fi]"
    puts -nonewline "[format {%-25.25s} [FencerName $fi]]"
  }
}


proc DumpTables { } {
  global DEF_ma_competition
  global table
  foreach tname $DEF_ma_competition(tableauxactifs) {
    #puts $table($tname)

    set matches [lfind $table($tname) les_matches]
    foreach m $matches {
	# {match {8 nobody {} {} 8 1 32}}
	# {match {14 11 13 12 14 17 16}} {imprime vrai} {piste_no {}} {heure {}}
    	set match [lfind $m match]
    	set strip [lfind $m piste_no]
    	set time [lfind $m heure]

	# break out the match data
	set fencer1 [lindex $match 0]
	set fencer2 [lindex $match 1]
	set points1 [lindex $match 2]
	set points2 [lindex $match 3]
	set winner  [lindex $match 4]
	set seed1 [lindex $match 5]
	set seed2 [lindex $match 6]

	putFencer $fencer1 $seed1
	puts ""
	puts -nonewline "                               "
   	puts "[format {%-25.25s} [FencerName $winner]]"
	putFencer $fencer2 $seed2
	if { $points1 < $points2 } {
	  puts "$points1/$points2"
	} else {
	  puts "$points1/$points2"
	}
	puts ""
    } 
  }
}

# DumpTables


proc Tables_HTML { out } {
  global tableSize
  global suite_tableaux

  puts $out "<p class=\"result_section\"><a name=\"DE\">Direct Eliminations</a></p>"

  foreach round [list a b c d] {
    if { [info exists tableSize($round)] } {
      array set rdata $suite_tableaux([string toupper $round])
      if { $round != "a" } {
        puts $out "<p class=\"subsection\">$rdata(nom_tableaux)</p>"
      }

      Tables_PrintRound_HTML $out $round
    }
  }
}


#
# This prints a round of DEs from N to 1
#
# Side Effects:
# As fencers drop out, their final_rank is calculated
#


proc Tables_PrintRound_HTML { out round } {
  global Competition Fencer
  global table
  global tableSize

  # puts "T size = $tableSize($round)"

  set maxrow [expr $tableSize($round) * 2]

    # The winners and losers from this round fill a certain set of
    # slots in the final rankings.  For the A round, that is
    # the normal positions.  For a B round, we are back filling
    # slots.   A B2 round should be for 3rd place, so I think
    # the right thing is ...
    # for Bn round, the slots are n+1...n+n
    set roundBase 1
    if { $round == "a" } {
	set roundBase 1
    } elseif { $round == "b" } {
    	set roundBase 3
    } elseif { $round == "c" } {
	# wild guess 2^2+1, based on a = 2^0 + 1, b=2^1+1
        set roundBase 5
    }

  #
  # roll down the tables from largest to smallest and get the match
  # data for each.    Transpose that into a vector (by column) of
  # who where the fencers and the # of points they got
  set col 0
  for { set tsize $tableSize($round) } { $tsize > 1 } { set tsize [expr $tsize / 2]} {
    # puts $table($round$tsize)
    set fl ""
    set sl ""
    set seeds ""
    set wlist {}
    set llist {}

    if { [ info exists table($round$tsize) ] } {
      set matches [lfind $table($round$tsize) les_matches]
      set colMatch($col) $matches

      foreach m $matches {
    	set match [lfind $m match]
	# break out the match data
	set fencer1 [lindex $match 0]
	set fencer2 [lindex $match 1]
	set points1 [lindex $match 2]
	set points2 [lindex $match 3]
	set winner  [lindex $match 4]
	set seed1 [lindex $match 5]
	set seed2 [lindex $match 6]
	lappend fl $fencer1 $fencer2
	lappend sl $points1 $points2
	lappend seeds $seed1 $seed2

	#
	# keep seeds up to date
	# we make a list of winners and losers and sort by initial seed
	# at the end of the round

	if { $winner == $fencer1 } {
	  if { $fencer1 != "" } { lappend wlist $fencer1 }
	  if { $fencer2 != "nobody" && $fencer2 != ""} {
	    lappend llist $fencer2
	  }
	} elseif { $winner == $fencer2 } {
	  # fencer 2 won the bout
          if { $fencer2 != "" } { lappend wlist $fencer2 }
	  if { $fencer1 != "nobody" && $fencer1 != ""} {
	    lappend llist $fencer1
	  }
	} else {
	  # bout has not happend yet
	  if { $seed1 < $seed2 } {
	    lappend wlist $fencer1
	    lappend llist $fencer2
	  } else {
	    lappend llist $fencer1
	    lappend wlist $fencer2
	  }
        }
      }
    } else {
      for { set i 0 } { $i < $tsize } { incr i } {
	lappend fl unset
	lappend sl {}
	lappend seeds {}
      }
      set winner unset
    }

    # puts $out "<br/>colFencer ($col) = $fl"
    set colFencer($col) $fl
    # puts $out "<br/>colPoints ($col) = $sl"
    set colPoints($col) $sl
    set colSeeds($col) $seeds

    incr col

    # Adjust the current rankings based on the winners and losers
    # of this round

    set i $roundBase
    # puts "<br/>winners: start rank at $i: $wlist"
    RankFencers $wlist $i
    incr i [llength $wlist]
    unset wlist
    # puts "<br/>losers: start rank at $i: $llist"
    RankFencers $llist $i
    unset llist

  }

  # now fake the fencer in the last column
  set colFencer($col) [list $winner]
  set colPoints($col) [list 15]
  set colSeeds($col) [list 1]
  if { $winner > 0 } {
    set Competition(haveFinal) 1
  }

  set nCols $col
  for { set col 0 } { $col <= [expr $nCols + 1]} { incr col } {
    set inBout($col) 0
  }

  # this next part is subtle

  puts $out "<table class=\"tableau\">"
  for { set row 1 } { $row <= $maxrow } { incr row } {

    # cpow is 2 ^ column.   We will a trick here that
    # in column 0, we want every other row to print
    # in column 1, we want every forth row to print
    # in column 2, we want every eighth row to print
    # ...
    set cpow 1
    puts $out "<tr>"
    set printedSomething 0


    for { set col 0 } { $col <= $nCols } { incr col } {

	# on the first column, we print the initial seeding
	set seed [lindex $colSeeds($col) 0]
	if { $col == 0 } {
          if { [expr $row & $cpow] != 0 } {
	    puts -nonewline $out "<td>[expr $roundBase - 1 + $seed]</td>"
	  } else {
	    puts -nonewline $out "<td>&nbsp;</td>"
          }
        }

      # we check the 
      if { $printedSomething == 0 && [expr $row & $cpow] != 0 } {
	# pick head off lists
	set fi [lindex $colFencer($col) 0]
	set pts [lindex $colPoints($col) 0]
	set seed [lindex $colSeeds($col) 0]
	# roll down lists
	set colFencer($col) [lrange $colFencer($col) 1 end]
	set colPoints($col) [lrange $colPoints($col) 1 end]
	set colSeeds($col) [lrange $colSeeds($col) 1 end]

        if { $fi == "unset" } {
	  puts -nonewline $out "<td class=\"t$col\">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</td>"
        } elseif { $fi == "nobody" } {
	  puts -nonewline $out "<td class=\"t$col\">&nbsp;bye</td>"
        } elseif { $fi == "" } {
	  puts -nonewline $out "<td class=\"t$col\" width=\"100\">&nbsp;</td>"
	} else {
	  #puts -nonewline $out "<td class=\"t$col\">[format {%-10.10s} [FencerLastname $fi ] ] </td>"
	  puts -nonewline $out "<td class=\"t$col\">[format {%s} [FencerLastname $fi ] ] </td>"
	}
        if { $col < $nCols } {
	  puts -nonewline $out "<td>$pts</td>"
        }
	if { $col < $nCols } {
		set inBout($col) [expr 1 - $inBout($col)]
	}
        set printedSomething 1
      } elseif { $inBout($col) == 1 } {
	puts -nonewline $out "<td></td>"
        puts -nonewline $out "<td class=\"trule\"></td>"
      } else {
	puts -nonewline $out "<td></td>"
        puts -nonewline $out "<td></td>"
      }
      set cpow [expr $cpow * 2]
    }

    puts $out "</tr>"
  }
  puts $out "</table>"
}


#
# End of routines for tableaux printing
#
#######################################################




###############################################
#
# Some routines to deal with printing
#

# set our default to HTML
set PrintStyle HTML

#
# Start the print document
#
proc Print_Begin { out } {
	global PrintStyle Competition

	if { [ info procs "DocumentStart_$PrintStyle" ] != "" } {
		DocumentStart_$PrintStyle $out
	}
	if { [ info procs "PrintHeader_$PrintStyle" ] != "" } {
		PrintHeader_$PrintStyle $out $Competition(title_long)
	}
	if { [ info procs BodyStart_$PrintStyle ] != "" } {
		BodyStart_$PrintStyle $out
	}
}


#
# finish up the document
#
proc Print_FinishUp { out } {
	global PrintStyle
	if { [ info procs BodyEnd_$PrintStyle ] != "" } {
		BodyEnd_$PrintStyle $out
	}
	if { [ info procs DocumentEnd_$PrintStyle ] != "" } {
		DocumentEnd_$PrintStyle $out
	}
}

#
# End routines to deal with printing
#
###############################################



###############################################
#
# Handle an Engarde Competition
#

proc DoCompetition { out } {

    global PrintStyle Fencer Competition

    InitCompetition
    Engarde_LoadCompetition
    CategorizeCompetition_USFA

    Print_Begin $out

    CalculateCompetitionGroup

    if { [ info proc "PrintCompetitionInfo_$PrintStyle" ] != "" } {
	PrintCompetitionInfo_${PrintStyle} $out
    }

    #
    # Who is in the tournement
    #
    PrintField_${PrintStyle} $out

    #
    # Do pools
    # 
    if { $Competition(phase) == "debut" } {
	Print_FinishUp $out
	return
    }
    Engarde_LoadPools

    for { set round 1 } { $round <= $Competition(nPoolRounds) } { incr round } {
      set filestring "claspou_init_$round.txt"
      if { [file exists $filestring] } {
	puts $out "<hr/>"
	DealWithRound $out $round
      }

      if { $round == $Competition(nPoolRounds) } {
	set heading "Ranking after pools"
      } else {
	set heading "Ranking at end of pool round $round"
      }
      if { [file exists "claspou_fin_$round.txt"] } {
	  global EndOfRoundData_$round
          PrintEndOfRound $out $round EndOfRoundData_$round $heading
      }
    }


if { 0 } {
    # There is no need to print this data since we printed each pool round
    if { [file exists "clas_fin_poules.txt"] } {
	global EndOfPoolsData
	puts $out "<hr/>"
	PrintEndOfRound $out $Competition(nPoolRounds) EndOfPoolsData "Ranking after pools"
    }
}

    # this may return 0 if we are still in pools or
    # if we finished pools, but have not started DEs
    if { ! [Engarde_LoadTables] } {
       Print_FinishUp $out
       return
    }

    # print the tableux
    puts $out "<hr/>"
    Tables_HTML $out

    if { $Competition(haveFinal) == 0 } {
    	PrintDETableIndex_HTML $out
    }
    CalculateCompetitionGroup

    puts $out "<hr/>"
    PrintFinal_HTML $out

    Print_FinishUp $out
}

#
###############################################


###############################################
#
# Handle USFA class change
#

proc DoUSFAClassChange { out } {
    global PrintStyle Fencer Competition


    InitCompetition
    Engarde_LoadCompetition
    CategorizeCompetition_USFA
    CalculateCompetitionGroup

    set PrintStyle PS
    Print_Begin $out

    PrintUSFAClassChanges_PS $out

    Print_FinishUp $out
}


proc ScanForCompetitions { } {

	set startFolder [pwd]

	glob -nocomplain "competition.egw"
	cd "$arg"
	DoCompetition stdout
	cd "$startFolder"
	set didACompetition 1
}




###############################################
#
# The actual main body
#

#
# set defaults
#
set PrintStyle HTML

#
# process command line
#

set startFolder [pwd]

set didACompetition 0
set whatToDo DoCompetition
set outExtension $HTML_extension

for { set optind 0} { $optind < [llength $argv] } {incr optind} {
	set arg [lindex $argv $optind]
	if { "$arg" == "--version" } {
		puts "Engarde to HTML $VERSION.  Copyright 2006, Tony Aiuto"
		exit
	}
	if { "$arg" == "-text" } {
		set PrintStyle "text"
		continue
	}
	if { "$arg" == "-classchange" } {
		set whatToDo "DoUSFAClassChange"
		set outExtension $PS_extension
		continue
	}
	if { "$arg" == "-scan" } {
		ScanForCompetitions
		exit
	}
	if { "$arg" == "-fred" } {
		set whatToDo "doFRED"
		set outExtension "frd"
		continue
	}
	if { "$arg" == "-icss" } {
		global INCLUDE_CSS_FILE
		set INCLUDE_CSS_FILE 1
		continue
	}

	if { [file isdirectory "$arg"] } {
	    if { ! [file isfile "$arg/competition.egw" ] } {
      		puts stderr "$arg is not an Engarde competition folder"
		continue
	    }
	    if { $arg == "." } {
	        set out stdout
	    } else {
	        set out [open "[FolderToFileName $arg].$outExtension" "w"]
	    }
	    cd "$arg"
            puts "Doing competition folder: $arg"

	    $whatToDo $out
	    close $out
	    cd "$startFolder"
	    set didACompetition 1
	}
}

if { 0 } {
  #
  # If there were no competition folders on the command line, try
  # the current folder
  #
 if { ! $didACompetition } {
    if { ! [file isfile "competition.egw" ] } {
	error "This is not an Engarde competition folder" "$startFolder"
    } else {
	DoCompetition stdout
    }
  }
}



#
# if we did any competitions, we can exit.   Otherwise
# we fall through to the GUI setup

if { $didACompetition } {
    exit
}



#####################################################################

# setup the GUI

set competitionFolder ""
set lastFolder "." 
set eventDir ""

proc GUI_PickDir { } {
	global competitionFolder
	global lastFolder

	set compFile [tk_getOpenFile -initialdir $lastFolder \
		-filetypes "{Competition {.egw}}" \
		-title "Select competition"]

	regsub "/competition.egw" $compFile "" competitionFolder

	if { $competitionFolder != "" } {
		set lastFolder $competitionFolder
	}

	wm title . $competitionFolder

	global compButtons
	foreach b $compButtons {
		$b configure -state normal
	}
}

proc GUI_PickEventDir { } {
	global eventDir competitionFolder lastFolder

	set compFile [tk_getOpenFile -initialdir $lastFolder \
		-filetypes "{Competition {.egw}}" \
		-title "Select competition"]
        
#        set compFile [tk_chooseDirectory -initialdir $lastFolder \
#                      -title "Select "]
        
	regsub "/competition.egw" $compFile "" competitionFolder
	if { $competitionFolder != "" } {
		set lastFolder $competitionFolder
		set eventFolder $competitionFolder
	}

	wm title . $competitionFolder

	#
	# turn on all buttons except the runsub command
	#
	global compButtons
	foreach b $compButtons {
		if {$b != ".fcommands.runsub" } {
			$b configure -state normal
		} else {
			$b configure -state disabled
		}
	}
}

proc GUI_PickTournamentDir { } {
	global eventFolder competitionFolder lastFolder

#	set compFile [tk_getOpenFile -initialdir $lastFolder \
#		-filetypes "{Competition {.egw}}" \
#		-title "Select competition"]

        set competitionFolder [tk_chooseDirectory -initialdir "$lastFolder" \
                      -title "Select "]

#	regsub "/competition.egw" $compFile "" competitionFolder
#	set lastFolder $competitionFolder

	wm title . $competitionFolder

	#
	# disable all commands except runsub
	#
	global compButtons
	foreach b $compButtons {
		if {$b == ".fcommands.runsub" } {
			$b configure -state normal
		} else {
			$b configure -state disabled
		}
	}
	# clear the eventFolder so we know we are in multi-mode
	set eventFolder $competitionFolder
}


proc GUI_Go { } {
	global competitionFolder
	global HTML_extension

	# puts "Do Comp: $competitionFolder"
	set startFolder [pwd]
	cd "$competitionFolder"
	set out [open "event.$HTML_extension" "w"]
	DoCompetition $out
	close $out
	cd $startFolder

	puts "Output in $competitionFolder/event.$HTML_extension"
}

proc GUI_doFRED { } {
	global competitionFolder

	set startFolder [pwd]
	cd "$competitionFolder"
	set out [open "upload.frd" "w"]
	doFRED $out
	close $out
	cd $startFolder
	puts "Output in $competitionFolder/upload.frd"
}


proc GUI_Sheets { } {
	global competitionFolder
	global HTML_extension

	# puts "Do Comp: $competitionFolder"
	set startFolder [pwd]
	cd "$competitionFolder"
	set out [open "event.$HTML_extension" "w"]

	DoSheets $out

	close $out
	cd $startFolder

	puts "Output in $competitionFolder/event.$HTML_extension"
}


# watch this competition

proc DoCurrent { } {
	global competitionFolder HTML_extension

	set outFile "[FolderToFileName $competitionFolder].$HTML_extension"

	set out [open "$outFile" "w"]
	set startFolder [pwd]
	cd "$competitionFolder"
	global timeStampOutput
	set timeStampOutput 1
	DoCompetition $out
	close $out
	cd $startFolder
	set timeStampOutput 0

	set targetFile $outFile
	regexp {^(.*)/([^/]*)$} $outFile junk junkpath targetFile

	#
	# push file to upload server
	#
	global UPLOAD_SERVER 
	if { [info exists UPLOAD_SERVER] } {
		global UPLOAD_DIR 
		UploadFile $UPLOAD_SERVER $UPLOAD_DIR $targetFile $outFile
	}

	set tid [after 2000 DoCurrent]
	#puts "Timer id = $tid"
}

proc GUI_Watch { } {
	after 1000 DoCurrent
	.fcommands.watch configure -text "Cancel Watch" -command GUI_StopWatch
	# wm iconify .
}

proc GUI_StopWatch { } {
	#puts "Existing timers are [after info]"
	after cancel [after info]
	.fcommands.watch configure -text "Watch" -command GUI_Watch
}

#
# RunSubs - recurse down a folder tree and generate HTML for all
# folders
#

proc RunSubs { } {
	global competitionFolder
	global HTML_extension
	global outputFolder
	global startFolder
        
 	set files [glob -directory $competitionFolder -nocomplain -type d *]
	foreach fname $files {
                if { [file isfile "$fname/competition.egw" ] } {
                        #tk_messageBox -message $fname -type ok                
                                # puts "Do Comp: $competitionFolder"
			set lastSlash [string last / $fname]

			set outFileName [ string range $fname [expr {$lastSlash+1}] end ]
			cd $outputFolder
			set out [open [file join $outputFolder $outFileName.$HTML_extension] "w"]
			cd "$fname"
			set competitionFolder $fname
			puts "Doing $competitionFolder"
			DoCompetition $out
			close $out
			cd $startFolder
			puts "Output in $competitionFolder/event.$HTML_extension"
		}
	}
        set competitionFolder $startFolder
	cd $startFolder

	# Do it again in 20 seconds
        set tid [after 20000 RunSubs]      
}

#
# RunSubFolders - Prepare to run all subfolders recursively
#	asks for an outputFolder first
#

proc GUI_RunSubFolders {} {
        global competitionFolder
        global outputFolder
        global startFolder

        set startFolder $competitionFolder
        cd "$competitionFolder"
        set outputFolder [tk_chooseDirectory -initialdir $competitionFolder \
                      -title "Select Output Folder"]
        .fcommands.runsub configure -text "Cancel Running Results" -command GUI_StopSubs
        RunSubs
}


proc GUI_StopSubs { } {
	#puts "Existing timers are [after info]"
	after cancel [after info]
	.fcommands.runsub configure -text "Running Results for all sub folders" -command GUI_RunSubFolders
}


proc GUI_setup { } {
	global competitionFolder VERSION
	set BGColor "#FFFFCC"

	# the title

	. configure -background $BGColor 

	label .title -text "Engarde to HTML $VERSION.  Copyright 2006, Tony Aiuto" -background lightgrey
	pack .title -side top -fill x

	label .instructions -text {
Pick an event or tournament folder and select a command
	} -justify c -anchor c -background $BGColor 
	pack .instructions -side top -pady 10 -fill x -anchor c

	# the folder chooser

	frame .eventfc -background $BGColor 
	pack .eventfc -side top -pady 10 -fill x

		label .eventfc.eventlabel -text "Event Folder: " -background $BGColor
		pack .eventfc.eventlabel -side left -fill y
                
                # make a frame that stretches when we expand
		frame .eventfc.ff -background $BGColor
		pack .eventfc.ff -anchor e -anchor w -fill x

	frame .fc -background $BGColor 
	pack .fc -side top -pady 10 -fill x

		# make a frame that stretches when we expand
		frame .fc.ff -background $BGColor
		pack .fc.ff -anchor e -anchor w -fill x

		button .fc.ff.pick -text "..." -command "GUI_PickDir"
		pack .fc.ff.pick -padx 5 -side right -fill y
		entry .fc.ff.fname -textvariable competitionFolder -width 60
		pack .fc.ff.fname -anchor e -anchor w -fill x

		button .eventfc.ff.pick -text "Select Event" -command "GUI_PickEventDir"
		pack .eventfc.ff.pick -padx 5 -side right -fill y
		entry .eventfc.ff.fname -textvariable competitionFolder -width 60
		pack .eventfc.ff.fname -anchor e -anchor w -fill x
                
                frame .eventfc.ff1 -background $BGColor
		pack .eventfc.ff1 -anchor e -anchor w -fill x
                

	frame .tournamentfc -background $BGColor 
	pack .tournamentfc -side top -pady 10 -fill x

                label .tournamentfc.tournamentlabel -text "Tournament Folder: " -background $BGColor
		pack .tournamentfc.tournamentlabel -side left -fill y
		
                # make a frame that stretches when we expand
		frame .tournamentfc.ff -background $BGColor
		pack .tournamentfc.ff -anchor e -anchor w -fill x

                frame .tournamentfc.ff1 -background $BGColor
		pack .tournamentfc.ff1 -anchor e -anchor w -fill x
                
                button .tournamentfc.ff1.pick -text "Select Tournament" -command "GUI_PickTournamentDir"
		pack .tournamentfc.ff1.pick -padx 5 -side right -fill y
		entry .tournamentfc.ff1.fname -textvariable competitionFolder -width 60
		pack .tournamentfc.ff1.fname -anchor e -anchor w -fill x



	#
	# The commands
	#
	frame .fcommands -background $BGColor 
	global compButtons
	set compButtons {}
	pack .fcommands -side top -pady 10 -anchor c

proc NewCommand { frame cname text command } {

	set objname ${frame}.$cname
	button $objname -text "$text" -command $command \
			-state disabled -width 40
	pack $objname -side top -pady 10
	return $objname
}

	set b [NewCommand .fcommands \
		go "Generate complete HTML" GUI_Go]
	lappend compButtons $b

	set b [NewCommand .fcommands \
		runsub "Run Results for all sub folders" GUI_RunSubFolders ]
	lappend compButtons $b

	set b [NewCommand .fcommands \
		gosheets "Generate 2 of 3 5-touch DE scoresheets" GUI_Sheets ]
	lappend compButtons $b

	set b [NewCommand .fcommands \
		watch "Watch" GUI_Watch ]
	lappend compButtons $b

	set b [NewCommand .fcommands \
		fred "Generate askFRED upload" GUI_doFRED ]
	lappend compButtons $b

	set b [NewCommand .fcommands exit "Exit" exit]
	$b configure -state normal
}


proc EnableCommands { } {
	global eventFolder compButtons

	if { $eventFolder == "" } {
		# turn off all buttons except the runsub command
		#
		foreach b $compButtons {
			if {$b == ".fcommands.runsub" } {
				$b configure -state normal
			} else {
				$b configure -state disabled
			}
		}
	} else {
		# turn them all on if we have an event
		foreach b $compButtons {
			$b configure -state normal
		}
		.fcommands.runsub configure -state disabled
	}
}

#
# End of GUI setup routines
#
###############################################


#
# If we fall down to this code, it means we didn't get any folders
# to proccess on the command line, so start up in interactive mode
#

GUI_setup

wm geometry . "+10+10"
