# fencing_fred.tcl - routines to deal with FRED data
#
# Copyright 2006, Tony Aiuto
#
# Author: Tony Aiuto, tony.aiuto@gmail.com
#


proc _printIndent { out level } {
	if { $level == "indent" } { set level 0 }
	for { set i 0 } { $i < $level } { incr i } {
		puts -nonewline $out "  "
	}
}

proc _OpenTag  { out indent tag } {
	_printIndent $out $indent
	puts -nonewline $out "<$tag"
}

proc _BeginTag  { out indent tag } {
	_printIndent $out $indent
	puts $out "<$tag>"
}

proc _EndTag  { out indent tag } {
	_printIndent $out $indent
	puts $out "</$tag>"
}


#
# doFRED - create a full .frd file
#

proc doFRED { out } {

	InitCompetition
	Engarde_LoadCompetition
	Engarde_LoadPools
	if { ! [Engarde_LoadTables] } return
	CalculateFinalRanks
	CalculateCompetitionGroup

	fred_print $out
}

proc fred_print { out } {
	global Competition Fencer
	global FRED_Gender FRED_Weapon

	set indent 0

	puts $out {<?xml version="1.0" encoding="iso-8859-1"?>}
	puts $out {<FencingData xmlns="http://www.askfred.net" xmlns:ft="http://www.fencingtime.com">}
	incr indent
	_printIndent $out $indent
	puts $out {<ImportExport APIVersion="3.0" load="up">}

	set FRED_Gender [string toupper [string index $Competition(sex) 0]]

	set FRED_Weapon ""
	if { $Competition(weapon) == "epee" } {
		set FRED_Weapon "Epee"
	} elseif { $Competition(weapon) == "foil" } {
		set FRED_Weapon "Foil"
	} elseif { $Competition(weapon) == "sabre" } {
		set FRED_Weapon "Sabre"
	}

	incr indent
	fred_tournament $out $indent
	fred_club_database $out $indent
	fred_fencer_database $out $indent
	incr indent -1

	incr indent
	_printIndent $out $indent
	puts $out {<TeamDatabase>}
	_printIndent $out $indent
	puts $out {</TeamDatabase>}
	incr indent -1

	_printIndent $out $indent
	puts $out {</ImportExport>}
	incr indent -1
	_printIndent $out $indent
	puts $out {</FencingData>}

}

#
# Emit a Fencer Record for FRED
#

proc fred_fencer { out indent FI } {
	global Competition Fencer
	global FRED_Gender FRED_Weapon

	array set x $Fencer($FI)
	_OpenTag $out $indent "Fencer"
	puts -nonewline $out " FencerID=\"$x(FRED_id)\""

	puts -nonewline $out " FirstName=\"$x(first_name)\""
	puts -nonewline $out " LastName=\"$x(last_name)\""
	puts -nonewline $out " ClubID=\"[FRED_clubid $x(club)]\""
	# puts -nonewline $out " DivisionID=\"31\""
	if { $x(birth_year) > 0 } {
		puts -nonewline $out " BirthYear=\"$x(birth_year)\""
	}
	puts -nonewline $out " Gender=\"$FRED_Gender\""

#  	puts -nonewline $out {<tr>}
#     	# puts -nonewline $out "<td>$x(index)</td>"
#     	puts -nonewline $out "<td>[ClubName $x(club)]</td>"
	puts $out {>}

	if { $FRED_Weapon != "" } {
		_printIndent $out [expr $indent + 1]
		puts $out "<Rating Weapon=\"$FRED_Weapon\">$x(usfa_rank)</Rating>"
	}
	_EndTag $out $indent "Fencer"
}

proc fred_fencer_database {out indent} {
	_BeginTag $out $indent "FencerDatabase"
	incr indent
	foreach i [FencersByName] {
		fred_fencer $out $indent $i
	}
	incr indent -1
	_EndTag $out $indent "FencerDatabase"
}


proc FRED_clubid { clubindex } {
	global Club

	if { [info exists Club($clubindex)] } {
		array set x $Club($clubindex)
		if { [info exists x(FRED_id) ] } {
			return $x(FRED_id)
		}
	}
	return "-$clubindex"
}

proc fred_club { out indent CI } {
	global Competition Club

	array set x $Club($CI)
	_OpenTag $out $indent "Club"
	puts -nonewline $out " ClubID=\"$x(FRED_id)\""
	#puts -nonewline $out " DivisionID="69""
	puts -nonewline $out " Name=\"$x(name)\""
	puts -nonewline $out " Abbreviation=\"$x(name)\""
	#puts -nonewline $out " City="""
	#puts -nonewline $out " State=""
	puts $out "/>"
}

proc fred_club_database { out indent } {
	global Competition Club

	_BeginTag $out $indent "ClubDatabase"
	incr indent
	foreach i [array names Club] {
		fred_club $out $indent $i
	}
	incr indent -1
	_EndTag $out $indent "ClubDatabase"
}

proc fred_tournament { out indent } { 
	global Competition

	_OpenTag $out $indent "Tournament"

	if { [info exists Competition(FRED_ID) ] } {
		puts -nonewline $out " TournamentID=\"$Competition(FRED_ID)\""
	} else {
		puts -nonewline $out " TournamentID=\"-1\""
	}
	puts -nonewline $out " Name=\"$Competition(title2)\""
	puts -nonewline $out " Location=\"$Competition(title4)\""
	#puts -nonewline $out " StartDate=\"2006-04-16\""
	#puts -nonewline $out " EndDate=\"2006-04-16\""
	puts $out {>}

	incr indent
	fred_event $out $indent
	incr indent -1
	_EndTag $out $indent "Tournament"
}

proc fred_EmitFencerResult { out indent FI } {
	global Competition Fencer
	global FRED_Gender FRED_Weapon

	array set x $Fencer($FI)

	_OpenTag $out $indent "Result"
	puts -nonewline $out " CompetitorID=\"$x(FRED_id)\""
	puts -nonewline $out " ClubID=\"[FRED_clubid $x(club)]\""
	# puts -nonewline $out " Excluded=\"False\""

	puts -nonewline $out " Place=\"$x(final_rank)\""
	puts -nonewline $out " RatingThen=\"$x(usfa_rank)\""
	if { $x(usfa_rank) != $x(final_usfa_rank) } {
	    puts -nonewline $out " RatingEarned=\"$x(final_usfa_rank)\""
	}
	puts -nonewline $out " Lname=\"$x(last_name)\""
	puts $out ">"
	_EndTag $out $indent "Result"
}


proc fred_event { out indent } { 
	global Competition
	global FRED_Gender FRED_Weapon

	_OpenTag $out $indent "Event"
	puts -nonewline $out " EventID=\"$Competition(FRED_id)\""
	puts -nonewline $out " Description=\"$Competition(title1)\""
	puts -nonewline $out " Weapon=\"$FRED_Weapon\""
	puts -nonewline $out " Gender=\"$FRED_Gender\""
	#puts -nonewline $out " AgeLimit=\"None\""
	#puts -nonewline $out " RatingLimit=\"Open\""
	puts -nonewline $out " Rating=\"$Competition(classification)\""
	#puts -nonewline $out " IsTeam=\"False\""
	puts -nonewline $out " Entries=\"$Competition(nFencers)\""
	puts $out {>}

	#
	# print final ranking of fencers
	#
	incr indent
	foreach i [FencersByRank] {
		fred_EmitFencerResult $out $indent $i
	}
	fred_EmitAllRoundData $out $indent

	incr indent -1
	_EndTag $out $indent "Event"
}


#
# print results from all rounds
#

proc fred_EmitAllRoundData { out indent } {
	global Competition

	_BeginTag $out $indent "RoundResults"
	incr indent
	for { set round 1 } { $round <= $Competition(nPoolRounds) } { incr round } {
		fred_EmitRoundData $out $indent $round
        }
	incr indent -1

#    if { [file exists "clas_fin_poules.txt"] } {
#	global EndOfPoolsData
#	puts $out "<hr/>"
#	PrintEndOfRound $out EndOfPoolsData "Ranking after pools"
#    }

	_EndTag $out $indent "RoundResults"
}


#
# print results from a rounds
#

proc fred_EmitRoundData { out indent round } {
	global Competition

	_OpenTag $out $indent "Round"
	puts $out " Seq=\"$round\" Type=\"Pool\" Desc=\"Round #$round - Pools\">"
	incr indent

	# show the competitors in the round
	# my guess is that this is the people at the start of the
	# round, because we would want to load them up regardless of
	# if they got black-carded and did not finish the round
        # <Competitor CompetitorID="13408" Seed="1" Status="P">
        # </Competitor>

	global FLIST Fencer
	foreach fi $FLIST($round) {
	    # establish fencer data
	    array set x $Fencer($fi)

	    _OpenTag $out $indent "Competitor"
	    puts -nonewline $out " CompetitorID=\"$x(FRED_id)\""
	    puts -nonewline $out " Seed=\"$x(seed)\""
	    puts -nonewline $out " Status=\"P\""
		puts -nonewline $out " LastName=\"$x(last_name)\""
	    puts $out ">"
	    _EndTag $out $indent "Competitor"
	}

	#
	# Now we do each pool in the round
	#
	global tour_de_poules PoolInfo
	array set PoolInfo $tour_de_poules($round)
	for { set pool 1 } { $pool <= $PoolInfo(nombre_poules) } { incr pool } {
		global Pool
		_OpenTag $out $indent "Pool"
		puts -nonewline $out " Seq=\"$pool\""
		puts $out ">"

		_EndTag $out $indent "Pool"
	}


#      if { $round < $Competition(nPoolRounds) } {
#        if { [file exists "claspou_fin_$round.txt"] } {
#	  global EndOfRoundData_$round
#          PrintEndOfRound $out EndOfRoundData_$round "Ranking at end of pool round $round"
#        }
#    }

	incr indent -1
	_EndTag $out $indent "Round"
}



set SAMPLE {
    <Tournament TournamentID="1685" Name="BCAF Annual Easter Egg Open (ME &amp; WF)" Location="Bucks County Academy of Fencing" StartDate="2006-04-16" EndDate="2006-04-16">
      <Event EventID="7440" Description="" Weapon="Foil" Gender="Women" AgeLimit="None" RatingLimit="Open" Rating="NR" IsTeam="False" Entries="4">
        <Result CompetitorID="7103" ClubID="157" Excluded="False" Place="1" RatingThen="C2006" RatingEarned="">
        </Result>
        <Result CompetitorID="13408" ClubID="157" Excluded="False" Place="2" RatingThen="C2006" RatingEarned="">
        </Result>
        <Result CompetitorID="12461" ClubID="157" Excluded="False" Place="3" RatingThen="D2003" RatingEarned="">
        </Result>
        <Result CompetitorID="15458" ClubID="157" Excluded="False" Place="3" RatingThen="D2005" RatingEarned="">
        </Result>
        <RoundResults>
          <Round Seq="1" Type="Pool" Desc="Round #1 - Pools">
            <Competitor CompetitorID="13408" Seed="1" Status="P">
            </Competitor>
            <Competitor CompetitorID="7103" Seed="2" Status="P">
            </Competitor>
            <Competitor CompetitorID="15458" Seed="3" Status="P">
            </Competitor>
            <Competitor CompetitorID="12461" Seed="4" Status="P">
            </Competitor>
            <Pool Seq="1">
              <Competitor CompetitorID="12461" Seed="4" CompetitorNum="1" Bouts="3" Victories="0" TS="7" TR="15" Ind="-8" Rank="4" />
              <Competitor CompetitorID="7103" Seed="2" CompetitorNum="2" Bouts="3" Victories="3" TS="15" TR="7" Ind="+8" Rank="1" />
              <Competitor CompetitorID="15458" Seed="3" CompetitorNum="3" Bouts="3" Victories="1" TS="7" TR="12" Ind="-5" Rank="3" />
              <Competitor CompetitorID="13408" Seed="1" CompetitorNum="4" Bouts="3" Victories="2" TS="14" TR="9" Ind="+5" Rank="2" />
              <Bout>
                <Competitor CompetitorID="12461" Score="3" Status="D" />
                <Competitor CompetitorID="7103" Score="5" Status="V" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="12461" Score="2" Status="D" />
                <Competitor CompetitorID="15458" Score="5" Status="V" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="12461" Score="2" Status="D" />
                <Competitor CompetitorID="13408" Score="5" Status="V" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="7103" Score="5" Status="V" />
                <Competitor CompetitorID="15458" Score="0" Status="D" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="7103" Score="5" Status="V" />
                <Competitor CompetitorID="13408" Score="4" Status="D" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="15458" Score="2" Status="D" />
                <Competitor CompetitorID="13408" Score="5" Status="V" />
              </Bout>
            </Pool>
          </Round>
          <Round Seq="2" Type="Pool" Desc="Round #2 - Pools">
            <Competitor CompetitorID="7103" Seed="1" Status="P">
            </Competitor>
            <Competitor CompetitorID="13408" Seed="2" Status="P">
            </Competitor>
            <Competitor CompetitorID="15458" Seed="3" Status="P">
            </Competitor>
            <Competitor CompetitorID="12461" Seed="4" Status="P">
            </Competitor>
            <Pool Seq="1">
              <Competitor CompetitorID="7103" Seed="1" CompetitorNum="1" Bouts="3" Victories="3" TS="15" TR="5" Ind="+10" Rank="1" />
              <Competitor CompetitorID="13408" Seed="2" CompetitorNum="2" Bouts="3" Victories="2" TS="14" TR="11" Ind="+3" Rank="2" />
              <Competitor CompetitorID="15458" Seed="3" CompetitorNum="3" Bouts="3" Victories="0" TS="6" TR="14" Ind="-8" Rank="4" />
              <Competitor CompetitorID="12461" Seed="4" CompetitorNum="4" Bouts="3" Victories="1" TS="8" TR="13" Ind="-5" Rank="3" />
              <Bout>
                <Competitor CompetitorID="7103" Score="5" Status="V" />
                <Competitor CompetitorID="13408" Score="4" Status="D" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="7103" Score="5" Status="V" />
                <Competitor CompetitorID="15458" Score="0" Status="D" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="7103" Score="5" Status="V" />
                <Competitor CompetitorID="12461" Score="1" Status="D" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="13408" Score="5" Status="V" />
                <Competitor CompetitorID="15458" Score="3" Status="D" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="13408" Score="5" Status="V" />
                <Competitor CompetitorID="12461" Score="3" Status="D" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="15458" Score="3" Status="D" />
                <Competitor CompetitorID="12461" Score="4" Status="V" />
              </Bout>
            </Pool>
          </Round>
          <Round Seq="3" Type="DE" Desc="Round #3 - Direct Elimination">
            <Competitor CompetitorID="7103" Seed="1" Status="P">
            </Competitor>
            <Competitor CompetitorID="13408" Seed="2" Status="P">
            </Competitor>
            <Competitor CompetitorID="12461" Seed="3" Status="P">
            </Competitor>
            <Competitor CompetitorID="15458" Seed="4" Status="P">
            </Competitor>
            <Table Seq="1" Of="4">
              <Bout Seq="1">
                <Competitor Called="1" CompetitorID="7103" Score="15" Status="V">
                </Competitor>
                <Competitor Called="2" CompetitorID="15458" Score="4" Status="D">
                </Competitor>
              </Bout>
              <Bout Seq="2">
                <Competitor Called="1" CompetitorID="12461" Score="6" Status="D">
                </Competitor>
                <Competitor Called="2" CompetitorID="13408" Score="15" Status="V">
                </Competitor>
              </Bout>
            </Table>
            <Table Seq="2" Of="2">
              <Bout Seq="1">
                <Competitor Called="1" CompetitorID="7103" Score="15" Status="V">
                </Competitor>
                <Competitor Called="2" CompetitorID="13408" Score="5" Status="D">
                </Competitor>
              </Bout>
            </Table>
          </Round>
        </RoundResults>
      </Event>
      <Event EventID="7441" Description="" Weapon="Epee" Gender="Men" AgeLimit="None" RatingLimit="Open" Rating="A2" IsTeam="False" Entries="34">
        <Result CompetitorID="7276" ClubID="157" Excluded="False" Place="1" RatingThen="B2005" RatingEarned="A2006">
        </Result>
        <Result CompetitorID="7284" ClubID="676" Excluded="False" Place="2" RatingThen="B2006" RatingEarned="">
        </Result>
        <Result CompetitorID="10776" ClubID="157" Excluded="False" Place="3" RatingThen="A2005" RatingEarned="">
        </Result>
        <Result CompetitorID="3014" ClubID="703" Excluded="False" Place="3" RatingThen="A2006" RatingEarned="">
        </Result>
        <Result CompetitorID="8252" ClubID="157" Excluded="False" Place="5" RatingThen="A2005" RatingEarned="">
        </Result>
        <Result CompetitorID="1536" ClubID="278" Excluded="False" Place="6" RatingThen="B2005" RatingEarned="">
        </Result>
        <Result CompetitorID="9862" ClubID="183" Excluded="False" Place="7" RatingThen="B2005" RatingEarned="">
        </Result>
        <Result CompetitorID="-1" ClubID="-1" Excluded="False" Place="8" RatingThen="D2005" RatingEarned="C2006">
        </Result>
        <Result CompetitorID="7268" ClubID="135" Excluded="False" Place="9" RatingThen="A2005" RatingEarned="">
        </Result>
        <Result CompetitorID="9201" ClubID="887" Excluded="False" Place="10" RatingThen="B2006" RatingEarned="">
        </Result>
        <Result CompetitorID="10644" ClubID="157" Excluded="False" Place="11" RatingThen="B2005" RatingEarned="">
        </Result>
        <Result CompetitorID="11108" ClubID="157" Excluded="False" Place="12" RatingThen="A2005" RatingEarned="">
        </Result>
        <Result CompetitorID="10762" ClubID="274" Excluded="False" Place="13" RatingThen="B2005" RatingEarned="">
        </Result>
        <Result CompetitorID="-2" ClubID="-1" Excluded="False" Place="14" RatingThen="U" RatingEarned="">
        </Result>
        <Result CompetitorID="4510" ClubID="483" Excluded="False" Place="15" RatingThen="B2005" RatingEarned="">
        </Result>
        <Result CompetitorID="6999" ClubID="806" Excluded="False" Place="16" RatingThen="D2005" RatingEarned="">
        </Result>
        <Result CompetitorID="1983" ClubID="135" Excluded="False" Place="17" RatingThen="B2005" RatingEarned="">
        </Result>
        <Result CompetitorID="1130" ClubID="157" Excluded="False" Place="18" RatingThen="U" RatingEarned="">
        </Result>
        <Result CompetitorID="7000" ClubID="806" Excluded="False" Place="19" RatingThen="U" RatingEarned="">
        </Result>
        <Result CompetitorID="9662" ClubID="301" Excluded="False" Place="20" RatingThen="E2006" RatingEarned="">
        </Result>
        <Result CompetitorID="11337" ClubID="157" Excluded="False" Place="21" RatingThen="E2005" RatingEarned="">
        </Result>
        <Result CompetitorID="-3" ClubID="135" Excluded="False" Place="22" RatingThen="B2004" RatingEarned="">
        </Result>
        <Result CompetitorID="14945" ClubID="157" Excluded="False" Place="23" RatingThen="D2006" RatingEarned="">
        </Result>
        <Result CompetitorID="10842" ClubID="274" Excluded="False" Place="24" RatingThen="U" RatingEarned="">
        </Result>
        <Result CompetitorID="13462" ClubID="274" Excluded="False" Place="24" RatingThen="U" RatingEarned="">
        </Result>
        <Result CompetitorID="11220" ClubID="135" Excluded="False" Place="26" RatingThen="U" RatingEarned="">
        </Result>
        <Result CompetitorID="13048" ClubID="745" Excluded="False" Place="27" RatingThen="E2005" RatingEarned="">
        </Result>
        <Result CompetitorID="15597" ClubID="157" Excluded="False" Place="28" RatingThen="U" RatingEarned="">
        </Result>
        <Result CompetitorID="17361" ClubID="157" Excluded="False" Place="29" RatingThen="U" RatingEarned="">
        </Result>
        <Result CompetitorID="16321" ClubID="157" Excluded="False" Place="30" RatingThen="U" RatingEarned="">
        </Result>
        <Result CompetitorID="10863" ClubID="157" Excluded="False" Place="31" RatingThen="U" RatingEarned="">
        </Result>
        <Result CompetitorID="10382" ClubID="-2" Excluded="False" Place="32" RatingThen="U" RatingEarned="">
        </Result>
        <Result CompetitorID="17637" ClubID="157" Excluded="False" Place="33" RatingThen="U" RatingEarned="">
        </Result>
        <Result CompetitorID="-4" ClubID="1156" Excluded="False" Place="34" RatingThen="U" RatingEarned="">
        </Result>
        <RoundResults>
          <Round Seq="1" Type="Pool" Desc="Round #1 - Pools">
            <Competitor CompetitorID="3014" Seed="1" Status="P">
            </Competitor>
            <Competitor CompetitorID="7268" Seed="2" Status="P">
            </Competitor>
            <Competitor CompetitorID="10776" Seed="3" Status="P">
            </Competitor>
            <Competitor CompetitorID="8252" Seed="4" Status="P">
            </Competitor>
            <Competitor CompetitorID="11108" Seed="5" Status="P">
            </Competitor>
            <Competitor CompetitorID="7284" Seed="6" Status="P">
            </Competitor>
            <Competitor CompetitorID="9201" Seed="7" Status="P">
            </Competitor>
            <Competitor CompetitorID="1536" Seed="8" Status="P">
            </Competitor>
            <Competitor CompetitorID="9862" Seed="9" Status="P">
            </Competitor>
            <Competitor CompetitorID="10644" Seed="10" Status="P">
            </Competitor>
            <Competitor CompetitorID="1983" Seed="11" Status="P">
            </Competitor>
            <Competitor CompetitorID="7276" Seed="12" Status="P">
            </Competitor>
            <Competitor CompetitorID="4510" Seed="13" Status="P">
            </Competitor>
            <Competitor CompetitorID="10762" Seed="14" Status="P">
            </Competitor>
            <Competitor CompetitorID="-3" Seed="15" Status="P">
            </Competitor>
            <Competitor CompetitorID="14945" Seed="16" Status="P">
            </Competitor>
            <Competitor CompetitorID="-1" Seed="17" Status="P">
            </Competitor>
            <Competitor CompetitorID="6999" Seed="18" Status="P">
            </Competitor>
            <Competitor CompetitorID="9662" Seed="19" Status="P">
            </Competitor>
            <Competitor CompetitorID="13048" Seed="20" Status="P">
            </Competitor>
            <Competitor CompetitorID="11337" Seed="21" Status="P">
            </Competitor>
            <Competitor CompetitorID="13462" Seed="22" Status="P">
            </Competitor>
            <Competitor CompetitorID="10842" Seed="23" Status="P">
            </Competitor>
            <Competitor CompetitorID="7000" Seed="24" Status="P">
            </Competitor>
            <Competitor CompetitorID="11220" Seed="25" Status="P">
            </Competitor>
            <Competitor CompetitorID="10863" Seed="26" Status="P">
            </Competitor>
            <Competitor CompetitorID="16321" Seed="27" Status="P">
            </Competitor>
            <Competitor CompetitorID="-2" Seed="28" Status="P">
            </Competitor>
            <Competitor CompetitorID="15597" Seed="29" Status="P">
            </Competitor>
            <Competitor CompetitorID="17637" Seed="30" Status="P">
            </Competitor>
            <Competitor CompetitorID="-4" Seed="31" Status="P">
            </Competitor>
            <Competitor CompetitorID="17361" Seed="32" Status="P">
            </Competitor>
            <Competitor CompetitorID="1130" Seed="33" Status="P">
            </Competitor>
            <Competitor CompetitorID="10382" Seed="34" Status="P">
            </Competitor>
            <Pool Seq="1">
              <Competitor CompetitorID="1130" Seed="33" CompetitorNum="1" Bouts="5" Victories="4" TS="19" TR="15" Ind="+4" Rank="1" />
              <Competitor CompetitorID="7276" Seed="12" CompetitorNum="2" Bouts="5" Victories="3" TS="20" TR="19" Ind="+1" Rank="3" />
              <Competitor CompetitorID="4510" Seed="13" CompetitorNum="3" Bouts="5" Victories="2" TS="16" TR="18" Ind="-2" Rank="4" />
              <Competitor CompetitorID="10842" Seed="23" CompetitorNum="4" Bouts="5" Victories="1" TS="14" TR="23" Ind="-9" Rank="6" />
              <Competitor CompetitorID="3014" Seed="1" CompetitorNum="5" Bouts="5" Victories="3" TS="21" TR="11" Ind="+10" Rank="2" />
              <Competitor CompetitorID="11220" Seed="25" CompetitorNum="6" Bouts="5" Victories="2" TS="18" TR="22" Ind="-4" Rank="5" />
              <Bout>
                <Competitor CompetitorID="1130" Score="5" Status="V" />
                <Competitor CompetitorID="7276" Score="2" Status="D" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="1130" Score="5" Status="V" />
                <Competitor CompetitorID="4510" Score="2" Status="D" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="1130" Score="4" Status="V" />
                <Competitor CompetitorID="10842" Score="3" Status="D" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="1130" Score="0" Status="D" />
                <Competitor CompetitorID="3014" Score="5" Status="V" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="1130" Score="5" Status="V" />
                <Competitor CompetitorID="11220" Score="3" Status="D" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="7276" Score="5" Status="V" />
                <Competitor CompetitorID="4510" Score="3" Status="D" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="7276" Score="5" Status="V" />
                <Competitor CompetitorID="10842" Score="4" Status="D" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="7276" Score="5" Status="V" />
                <Competitor CompetitorID="3014" Score="2" Status="D" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="7276" Score="3" Status="D" />
                <Competitor CompetitorID="11220" Score="5" Status="V" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="4510" Score="5" Status="V" />
                <Competitor CompetitorID="10842" Score="2" Status="D" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="4510" Score="1" Status="D" />
                <Competitor CompetitorID="3014" Score="5" Status="V" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="4510" Score="5" Status="V" />
                <Competitor CompetitorID="11220" Score="1" Status="D" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="10842" Score="0" Status="D" />
                <Competitor CompetitorID="3014" Score="5" Status="V" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="10842" Score="5" Status="V" />
                <Competitor CompetitorID="11220" Score="4" Status="D" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="3014" Score="4" Status="D" />
                <Competitor CompetitorID="11220" Score="5" Status="V" />
              </Bout>
            </Pool>
            <Pool Seq="2">
              <Competitor CompetitorID="17361" Seed="32" CompetitorNum="1" Bouts="5" Victories="1" TS="11" TR="23" Ind="-12" Rank="5" />
              <Competitor CompetitorID="10863" Seed="26" CompetitorNum="2" Bouts="5" Victories="0" TS="15" TR="25" Ind="-10" Rank="6" />
              <Competitor CompetitorID="10762" Seed="14" CompetitorNum="3" Bouts="5" Victories="3" TS="22" TR="17" Ind="+5" Rank="2" />
              <Competitor CompetitorID="9862" Seed="9" CompetitorNum="4" Bouts="5" Victories="3" TS="22" TR="17" Ind="+5" Rank="2" />
              <Competitor CompetitorID="7268" Seed="2" CompetitorNum="5" Bouts="5" Victories="5" TS="25" TR="9" Ind="+16" Rank="1" />
              <Competitor CompetitorID="7000" Seed="24" CompetitorNum="6" Bouts="5" Victories="3" TS="16" TR="20" Ind="-4" Rank="4" />
              <Bout>
                <Competitor CompetitorID="17361" Score="5" Status="V" />
                <Competitor CompetitorID="10863" Score="3" Status="D" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="17361" Score="0" Status="D" />
                <Competitor CompetitorID="10762" Score="5" Status="V" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="17361" Score="4" Status="D" />
                <Competitor CompetitorID="9862" Score="5" Status="V" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="17361" Score="0" Status="D" />
                <Competitor CompetitorID="7268" Score="5" Status="V" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="17361" Score="2" Status="D" />
                <Competitor CompetitorID="7000" Score="5" Status="V" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="10863" Score="3" Status="D" />
                <Competitor CompetitorID="10762" Score="5" Status="V" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="10863" Score="2" Status="D" />
                <Competitor CompetitorID="9862" Score="5" Status="V" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="10863" Score="3" Status="D" />
                <Competitor CompetitorID="7268" Score="5" Status="V" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="10863" Score="4" Status="D" />
                <Competitor CompetitorID="7000" Score="5" Status="V" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="10762" Score="5" Status="V" />
                <Competitor CompetitorID="9862" Score="4" Status="D" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="10762" Score="3" Status="D" />
                <Competitor CompetitorID="7268" Score="5" Status="V" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="10762" Score="4" Status="D" />
                <Competitor CompetitorID="7000" Score="5" Status="V" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="9862" Score="3" Status="D" />
                <Competitor CompetitorID="7268" Score="5" Status="V" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="9862" Score="5" Status="V" />
                <Competitor CompetitorID="7000" Score="1" Status="D" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="7268" Score="5" Status="V" />
                <Competitor CompetitorID="7000" Score="0" Status="D" />
              </Bout>
            </Pool>
            <Pool Seq="3">
              <Competitor CompetitorID="10776" Seed="3" CompetitorNum="1" Bouts="5" Victories="5" TS="25" TR="9" Ind="+16" Rank="1" />
              <Competitor CompetitorID="16321" Seed="27" CompetitorNum="2" Bouts="5" Victories="1" TS="13" TR="22" Ind="-9" Rank="5" />
              <Competitor CompetitorID="13462" Seed="22" CompetitorNum="3" Bouts="5" Victories="3" TS="20" TR="17" Ind="+3" Rank="3" />
              <Competitor CompetitorID="-3" Seed="15" CompetitorNum="4" Bouts="5" Victories="2" TS="17" TR="17" Ind="0" Rank="4" />
              <Competitor CompetitorID="9201" Seed="7" CompetitorNum="5" Bouts="5" Victories="4" TS="23" TR="11" Ind="+12" Rank="2" />
              <Competitor CompetitorID="-4" Seed="31" CompetitorNum="6" Bouts="5" Victories="0" TS="3" TR="25" Ind="-22" Rank="6" />
              <Bout>
                <Competitor CompetitorID="10776" Score="5" Status="V" />
                <Competitor CompetitorID="16321" Score="1" Status="D" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="10776" Score="5" Status="V" />
                <Competitor CompetitorID="13462" Score="2" Status="D" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="10776" Score="5" Status="V" />
                <Competitor CompetitorID="-3" Score="3" Status="D" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="10776" Score="5" Status="V" />
                <Competitor CompetitorID="9201" Score="3" Status="D" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="10776" Score="5" Status="V" />
                <Competitor CompetitorID="-4" Score="0" Status="D" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="16321" Score="4" Status="D" />
                <Competitor CompetitorID="13462" Score="5" Status="V" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="16321" Score="1" Status="D" />
                <Competitor CompetitorID="-3" Score="5" Status="V" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="16321" Score="2" Status="D" />
                <Competitor CompetitorID="9201" Score="5" Status="V" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="16321" Score="5" Status="V" />
                <Competitor CompetitorID="-4" Score="2" Status="D" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="13462" Score="5" Status="V" />
                <Competitor CompetitorID="-3" Score="3" Status="D" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="13462" Score="3" Status="D" />
                <Competitor CompetitorID="9201" Score="5" Status="V" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="13462" Score="5" Status="V" />
                <Competitor CompetitorID="-4" Score="0" Status="D" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="-3" Score="1" Status="D" />
                <Competitor CompetitorID="9201" Score="5" Status="V" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="-3" Score="5" Status="V" />
                <Competitor CompetitorID="-4" Score="1" Status="D" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="9201" Score="5" Status="V" />
                <Competitor CompetitorID="-4" Score="0" Status="D" />
              </Bout>
            </Pool>
            <Pool Seq="4">
              <Competitor CompetitorID="17637" Seed="30" CompetitorNum="1" Bouts="5" Victories="0" TS="8" TR="25" Ind="-17" Rank="6" />
              <Competitor CompetitorID="8252" Seed="4" CompetitorNum="2" Bouts="5" Victories="4" TS="23" TR="16" Ind="+7" Rank="2" />
              <Competitor CompetitorID="11337" Seed="21" CompetitorNum="3" Bouts="5" Victories="2" TS="17" TR="21" Ind="-4" Rank="5" />
              <Competitor CompetitorID="1983" Seed="11" CompetitorNum="4" Bouts="5" Victories="4" TS="24" TR="15" Ind="+9" Rank="1" />
              <Competitor CompetitorID="-2" Seed="28" CompetitorNum="5" Bouts="5" Victories="3" TS="20" TR="19" Ind="+1" Rank="3" />
              <Competitor CompetitorID="6999" Seed="18" CompetitorNum="6" Bouts="5" Victories="2" TS="21" TR="17" Ind="+4" Rank="4" />
              <Bout>
                <Competitor CompetitorID="17637" Score="1" Status="D" />
                <Competitor CompetitorID="8252" Score="5" Status="V" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="17637" Score="2" Status="D" />
                <Competitor CompetitorID="11337" Score="5" Status="V" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="17637" Score="2" Status="D" />
                <Competitor CompetitorID="1983" Score="5" Status="V" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="17637" Score="2" Status="D" />
                <Competitor CompetitorID="-2" Score="5" Status="V" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="17637" Score="1" Status="D" />
                <Competitor CompetitorID="6999" Score="5" Status="V" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="8252" Score="5" Status="V" />
                <Competitor CompetitorID="11337" Score="2" Status="D" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="8252" Score="5" Status="V" />
                <Competitor CompetitorID="1983" Score="4" Status="D" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="8252" Score="3" Status="D" />
                <Competitor CompetitorID="-2" Score="5" Status="V" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="8252" Score="5" Status="V" />
                <Competitor CompetitorID="6999" Score="4" Status="D" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="11337" Score="4" Status="D" />
                <Competitor CompetitorID="1983" Score="5" Status="V" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="11337" Score="5" Status="V" />
                <Competitor CompetitorID="-2" Score="4" Status="D" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="11337" Score="1" Status="D" />
                <Competitor CompetitorID="6999" Score="5" Status="V" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="1983" Score="5" Status="V" />
                <Competitor CompetitorID="-2" Score="1" Status="D" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="1983" Score="5" Status="V" />
                <Competitor CompetitorID="6999" Score="3" Status="D" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="-2" Score="5" Status="V" />
                <Competitor CompetitorID="6999" Score="4" Status="D" />
              </Bout>
            </Pool>
            <Pool Seq="5">
              <Competitor CompetitorID="15597" Seed="29" CompetitorNum="1" Bouts="4" Victories="2" TS="17" TR="18" Ind="-1" Rank="4" />
              <Competitor CompetitorID="11108" Seed="5" CompetitorNum="2" Bouts="4" Victories="3" TS="17" TR="13" Ind="+4" Rank="1" />
              <Competitor CompetitorID="1536" Seed="8" CompetitorNum="3" Bouts="4" Victories="3" TS="16" TR="16" Ind="0" Rank="2" />
              <Competitor CompetitorID="13048" Seed="20" CompetitorNum="4" Bouts="4" Victories="0" TS="14" TR="20" Ind="-6" Rank="5" />
              <Competitor CompetitorID="-1" Seed="17" CompetitorNum="5" Bouts="4" Victories="2" TS="18" TR="15" Ind="+3" Rank="3" />
              <Bout>
                <Competitor CompetitorID="15597" Score="4" Status="D" />
                <Competitor CompetitorID="11108" Score="5" Status="V" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="15597" Score="3" Status="D" />
                <Competitor CompetitorID="1536" Score="5" Status="V" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="15597" Score="5" Status="V" />
                <Competitor CompetitorID="13048" Score="4" Status="D" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="15597" Score="5" Status="V" />
                <Competitor CompetitorID="-1" Score="4" Status="D" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="11108" Score="5" Status="V" />
                <Competitor CompetitorID="1536" Score="1" Status="D" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="11108" Score="5" Status="V" />
                <Competitor CompetitorID="13048" Score="3" Status="D" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="11108" Score="2" Status="D" />
                <Competitor CompetitorID="-1" Score="5" Status="V" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="1536" Score="5" Status="V" />
                <Competitor CompetitorID="13048" Score="4" Status="D" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="1536" Score="5" Status="V" />
                <Competitor CompetitorID="-1" Score="4" Status="D" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="13048" Score="3" Status="D" />
                <Competitor CompetitorID="-1" Score="5" Status="V" />
              </Bout>
            </Pool>
            <Pool Seq="6">
              <Competitor CompetitorID="14945" Seed="16" CompetitorNum="1" Bouts="4" Victories="1" TS="11" TR="18" Ind="-7" Rank="4" />
              <Competitor CompetitorID="10644" Seed="10" CompetitorNum="2" Bouts="4" Victories="4" TS="19" TR="9" Ind="+10" Rank="1" />
              <Competitor CompetitorID="9662" Seed="19" CompetitorNum="3" Bouts="4" Victories="2" TS="13" TR="14" Ind="-1" Rank="3" />
              <Competitor CompetitorID="10382" Seed="34" CompetitorNum="4" Bouts="4" Victories="0" TS="10" TR="17" Ind="-7" Rank="5" />
              <Competitor CompetitorID="7284" Seed="6" CompetitorNum="5" Bouts="4" Victories="3" TS="18" TR="13" Ind="+5" Rank="2" />
              <Bout>
                <Competitor CompetitorID="14945" Score="2" Status="D" />
                <Competitor CompetitorID="10644" Score="5" Status="V" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="14945" Score="2" Status="D" />
                <Competitor CompetitorID="9662" Score="5" Status="V" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="14945" Score="4" Status="V" />
                <Competitor CompetitorID="10382" Score="3" Status="D" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="14945" Score="3" Status="D" />
                <Competitor CompetitorID="7284" Score="5" Status="V" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="10644" Score="5" Status="V" />
                <Competitor CompetitorID="9662" Score="1" Status="D" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="10644" Score="4" Status="V" />
                <Competitor CompetitorID="10382" Score="2" Status="D" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="10644" Score="5" Status="V" />
                <Competitor CompetitorID="7284" Score="4" Status="D" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="9662" Score="5" Status="V" />
                <Competitor CompetitorID="10382" Score="2" Status="D" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="9662" Score="2" Status="D" />
                <Competitor CompetitorID="7284" Score="5" Status="V" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="10382" Score="3" Status="D" />
                <Competitor CompetitorID="7284" Score="4" Status="V" />
              </Bout>
            </Pool>
          </Round>
          <Round Seq="2" Type="Pool" Desc="Round #2 - Pools">
            <Competitor CompetitorID="10776" Seed="1T" Status="P">
            </Competitor>
            <Competitor CompetitorID="7268" Seed="1T" Status="P">
            </Competitor>
            <Competitor CompetitorID="10644" Seed="3" Status="P">
            </Competitor>
            <Competitor CompetitorID="9201" Seed="4" Status="P">
            </Competitor>
            <Competitor CompetitorID="1983" Seed="5" Status="P">
            </Competitor>
            <Competitor CompetitorID="8252" Seed="6" Status="P">
            </Competitor>
            <Competitor CompetitorID="1130" Seed="7" Status="P">
            </Competitor>
            <Competitor CompetitorID="7284" Seed="8" Status="P">
            </Competitor>
            <Competitor CompetitorID="11108" Seed="9" Status="P">
            </Competitor>
            <Competitor CompetitorID="1536" Seed="10" Status="P">
            </Competitor>
            <Competitor CompetitorID="3014" Seed="11" Status="P">
            </Competitor>
            <Competitor CompetitorID="9862" Seed="12T" Status="P">
            </Competitor>
            <Competitor CompetitorID="10762" Seed="12T" Status="P">
            </Competitor>
            <Competitor CompetitorID="13462" Seed="14" Status="P">
            </Competitor>
            <Competitor CompetitorID="-2" Seed="15T" Status="P">
            </Competitor>
            <Competitor CompetitorID="7276" Seed="15T" Status="P">
            </Competitor>
            <Competitor CompetitorID="7000" Seed="17" Status="P">
            </Competitor>
            <Competitor CompetitorID="-1" Seed="18" Status="P">
            </Competitor>
            <Competitor CompetitorID="15597" Seed="19" Status="P">
            </Competitor>
            <Competitor CompetitorID="9662" Seed="20" Status="P">
            </Competitor>
            <Competitor CompetitorID="6999" Seed="21" Status="P">
            </Competitor>
            <Competitor CompetitorID="-3" Seed="22" Status="P">
            </Competitor>
            <Competitor CompetitorID="4510" Seed="23" Status="P">
            </Competitor>
            <Competitor CompetitorID="11220" Seed="24" Status="P">
            </Competitor>
            <Competitor CompetitorID="11337" Seed="25" Status="P">
            </Competitor>
            <Competitor CompetitorID="14945" Seed="26" Status="P">
            </Competitor>
            <Competitor CompetitorID="10842" Seed="27" Status="P">
            </Competitor>
            <Competitor CompetitorID="16321" Seed="28" Status="P">
            </Competitor>
            <Competitor CompetitorID="17361" Seed="29" Status="P">
            </Competitor>
            <Competitor CompetitorID="13048" Seed="30" Status="P">
            </Competitor>
            <Competitor CompetitorID="10382" Seed="31" Status="P">
            </Competitor>
            <Competitor CompetitorID="10863" Seed="32" Status="P">
            </Competitor>
            <Competitor CompetitorID="17637" Seed="33" Status="P">
            </Competitor>
            <Competitor CompetitorID="-4" Seed="34" Status="P">
            </Competitor>
            <Pool Seq="1">
              <Competitor CompetitorID="10776" Seed="1T" CompetitorNum="1" Bouts="5" Victories="4" TS="22" TR="16" Ind="+6" Rank="2" />
              <Competitor CompetitorID="11337" Seed="25" CompetitorNum="2" Bouts="5" Victories="3" TS="21" TR="20" Ind="+1" Rank="4" />
              <Competitor CompetitorID="10762" Seed="12T" CompetitorNum="3" Bouts="5" Victories="3" TS="21" TR="16" Ind="+5" Rank="3" />
              <Competitor CompetitorID="11220" Seed="24" CompetitorNum="4" Bouts="5" Victories="1" TS="15" TR="24" Ind="-9" Rank="5" />
              <Competitor CompetitorID="9862" Seed="12T" CompetitorNum="5" Bouts="5" Victories="4" TS="24" TR="13" Ind="+11" Rank="1" />
              <Competitor CompetitorID="10382" Seed="31" CompetitorNum="6" Bouts="5" Victories="0" TS="11" TR="25" Ind="-14" Rank="6" />
              <Bout>
                <Competitor CompetitorID="10776" Score="5" Status="V" />
                <Competitor CompetitorID="11337" Score="2" Status="D" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="10776" Score="2" Status="D" />
                <Competitor CompetitorID="10762" Score="5" Status="V" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="10776" Score="5" Status="V" />
                <Competitor CompetitorID="11220" Score="4" Status="D" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="10776" Score="5" Status="V" />
                <Competitor CompetitorID="9862" Score="4" Status="D" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="10776" Score="5" Status="V" />
                <Competitor CompetitorID="10382" Score="1" Status="D" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="11337" Score="5" Status="V" />
                <Competitor CompetitorID="10762" Score="4" Status="D" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="11337" Score="5" Status="V" />
                <Competitor CompetitorID="11220" Score="4" Status="D" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="11337" Score="4" Status="D" />
                <Competitor CompetitorID="9862" Score="5" Status="V" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="11337" Score="5" Status="V" />
                <Competitor CompetitorID="10382" Score="2" Status="D" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="10762" Score="5" Status="V" />
                <Competitor CompetitorID="11220" Score="2" Status="D" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="10762" Score="2" Status="D" />
                <Competitor CompetitorID="9862" Score="5" Status="V" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="10762" Score="5" Status="V" />
                <Competitor CompetitorID="10382" Score="2" Status="D" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="11220" Score="0" Status="D" />
                <Competitor CompetitorID="9862" Score="5" Status="V" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="11220" Score="5" Status="V" />
                <Competitor CompetitorID="10382" Score="4" Status="D" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="9862" Score="5" Status="V" />
                <Competitor CompetitorID="10382" Score="2" Status="D" />
              </Bout>
            </Pool>
            <Pool Seq="2">
              <Competitor CompetitorID="14945" Seed="26" CompetitorNum="1" Bouts="5" Victories="2" TS="16" TR="21" Ind="-5" Rank="4" />
              <Competitor CompetitorID="10863" Seed="32" CompetitorNum="2" Bouts="5" Victories="1" TS="14" TR="22" Ind="-8" Rank="5" />
              <Competitor CompetitorID="13462" Seed="14" CompetitorNum="3" Bouts="5" Victories="0" TS="13" TR="25" Ind="-12" Rank="6" />
              <Competitor CompetitorID="4510" Seed="23" CompetitorNum="4" Bouts="5" Victories="3" TS="18" TR="19" Ind="-1" Rank="3" />
              <Competitor CompetitorID="7268" Seed="1T" CompetitorNum="5" Bouts="5" Victories="4" TS="24" TR="13" Ind="+11" Rank="2" />
              <Competitor CompetitorID="3014" Seed="11" CompetitorNum="6" Bouts="5" Victories="5" TS="25" TR="10" Ind="+15" Rank="1" />
              <Bout>
                <Competitor CompetitorID="14945" Score="5" Status="V" />
                <Competitor CompetitorID="10863" Score="2" Status="D" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="14945" Score="5" Status="V" />
                <Competitor CompetitorID="13462" Score="4" Status="D" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="14945" Score="2" Status="D" />
                <Competitor CompetitorID="4510" Score="5" Status="V" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="14945" Score="2" Status="D" />
                <Competitor CompetitorID="7268" Score="5" Status="V" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="14945" Score="2" Status="D" />
                <Competitor CompetitorID="3014" Score="5" Status="V" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="10863" Score="5" Status="V" />
                <Competitor CompetitorID="13462" Score="2" Status="D" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="10863" Score="4" Status="D" />
                <Competitor CompetitorID="4510" Score="5" Status="V" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="10863" Score="2" Status="D" />
                <Competitor CompetitorID="7268" Score="5" Status="V" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="10863" Score="1" Status="D" />
                <Competitor CompetitorID="3014" Score="5" Status="V" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="13462" Score="3" Status="D" />
                <Competitor CompetitorID="4510" Score="5" Status="V" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="13462" Score="2" Status="D" />
                <Competitor CompetitorID="7268" Score="5" Status="V" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="13462" Score="2" Status="D" />
                <Competitor CompetitorID="3014" Score="5" Status="V" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="4510" Score="2" Status="D" />
                <Competitor CompetitorID="7268" Score="5" Status="V" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="4510" Score="1" Status="D" />
                <Competitor CompetitorID="3014" Score="5" Status="V" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="7268" Score="4" Status="D" />
                <Competitor CompetitorID="3014" Score="5" Status="V" />
              </Bout>
            </Pool>
            <Pool Seq="3">
              <Competitor CompetitorID="10644" Seed="3" CompetitorNum="1" Bouts="5" Victories="3" TS="18" TR="12" Ind="+6" Rank="2" />
              <Competitor CompetitorID="17637" Seed="33" CompetitorNum="2" Bouts="5" Victories="0" TS="8" TR="25" Ind="-17" Rank="6" />
              <Competitor CompetitorID="-2" Seed="15T" CompetitorNum="3" Bouts="5" Victories="3" TS="19" TR="17" Ind="+2" Rank="3" />
              <Competitor CompetitorID="-3" Seed="22" CompetitorNum="4" Bouts="5" Victories="2" TS="13" TR="19" Ind="-6" Rank="5" />
              <Competitor CompetitorID="10842" Seed="27" CompetitorNum="5" Bouts="5" Victories="2" TS="19" TR="19" Ind="0" Rank="4" />
              <Competitor CompetitorID="1536" Seed="10" CompetitorNum="6" Bouts="5" Victories="5" TS="24" TR="9" Ind="+15" Rank="1" />
              <Bout>
                <Competitor CompetitorID="10644" Score="5" Status="V" />
                <Competitor CompetitorID="17637" Score="0" Status="D" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="10644" Score="3" Status="D" />
                <Competitor CompetitorID="-2" Score="5" Status="V" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="10644" Score="5" Status="V" />
                <Competitor CompetitorID="-3" Score="0" Status="D" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="10644" Score="5" Status="V" />
                <Competitor CompetitorID="10842" Score="2" Status="D" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="10644" Score="0" Status="D" />
                <Competitor CompetitorID="1536" Score="5" Status="V" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="17637" Score="2" Status="D" />
                <Competitor CompetitorID="-2" Score="5" Status="V" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="17637" Score="2" Status="D" />
                <Competitor CompetitorID="-3" Score="5" Status="V" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="17637" Score="2" Status="D" />
                <Competitor CompetitorID="10842" Score="5" Status="V" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="17637" Score="2" Status="D" />
                <Competitor CompetitorID="1536" Score="5" Status="V" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="-2" Score="3" Status="D" />
                <Competitor CompetitorID="-3" Score="4" Status="V" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="-2" Score="5" Status="V" />
                <Competitor CompetitorID="10842" Score="3" Status="D" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="-2" Score="1" Status="D" />
                <Competitor CompetitorID="1536" Score="5" Status="V" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="-3" Score="2" Status="D" />
                <Competitor CompetitorID="10842" Score="5" Status="V" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="-3" Score="2" Status="D" />
                <Competitor CompetitorID="1536" Score="4" Status="V" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="10842" Score="4" Status="D" />
                <Competitor CompetitorID="1536" Score="5" Status="V" />
              </Bout>
            </Pool>
            <Pool Seq="4">
              <Competitor CompetitorID="16321" Seed="28" CompetitorNum="1" Bouts="5" Victories="1" TS="13" TR="20" Ind="-7" Rank="5" />
              <Competitor CompetitorID="11108" Seed="9" CompetitorNum="2" Bouts="5" Victories="4" TS="21" TR="10" Ind="+11" Rank="1" />
              <Competitor CompetitorID="7276" Seed="15T" CompetitorNum="3" Bouts="5" Victories="4" TS="22" TR="12" Ind="+10" Rank="2" />
              <Competitor CompetitorID="6999" Seed="21" CompetitorNum="4" Bouts="5" Victories="2" TS="17" TR="14" Ind="+3" Rank="4" />
              <Competitor CompetitorID="9201" Seed="4" CompetitorNum="5" Bouts="5" Victories="4" TS="21" TR="13" Ind="+8" Rank="3" />
              <Competitor CompetitorID="-4" Seed="34" CompetitorNum="6" Bouts="5" Victories="0" TS="0" TR="25" Ind="-25" Rank="6" />
              <Bout>
                <Competitor CompetitorID="16321" Score="1" Status="D" />
                <Competitor CompetitorID="11108" Score="5" Status="V" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="16321" Score="3" Status="D" />
                <Competitor CompetitorID="7276" Score="5" Status="V" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="16321" Score="1" Status="D" />
                <Competitor CompetitorID="6999" Score="5" Status="V" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="16321" Score="3" Status="D" />
                <Competitor CompetitorID="9201" Score="5" Status="V" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="16321" Score="5" Status="V" />
                <Competitor CompetitorID="-4" Score="0" Status="D" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="11108" Score="5" Status="V" />
                <Competitor CompetitorID="7276" Score="2" Status="D" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="11108" Score="3" Status="V" />
                <Competitor CompetitorID="6999" Score="2" Status="D" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="11108" Score="3" Status="D" />
                <Competitor CompetitorID="9201" Score="5" Status="V" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="11108" Score="5" Status="V" />
                <Competitor CompetitorID="-4" Score="0" Status="D" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="7276" Score="5" Status="V" />
                <Competitor CompetitorID="6999" Score="3" Status="D" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="7276" Score="5" Status="V" />
                <Competitor CompetitorID="9201" Score="1" Status="D" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="7276" Score="5" Status="V" />
                <Competitor CompetitorID="-4" Score="0" Status="D" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="6999" Score="2" Status="D" />
                <Competitor CompetitorID="9201" Score="5" Status="V" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="6999" Score="5" Status="V" />
                <Competitor CompetitorID="-4" Score="0" Status="D" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="9201" Score="5" Status="V" />
                <Competitor CompetitorID="-4" Score="0" Status="D" />
              </Bout>
            </Pool>
            <Pool Seq="5">
              <Competitor CompetitorID="1983" Seed="5" CompetitorNum="1" Bouts="4" Victories="2" TS="16" TR="13" Ind="+3" Rank="2" />
              <Competitor CompetitorID="7284" Seed="8" CompetitorNum="2" Bouts="4" Victories="3" TS="19" TR="12" Ind="+7" Rank="1" />
              <Competitor CompetitorID="7000" Seed="17" CompetitorNum="3" Bouts="4" Victories="2" TS="14" TR="17" Ind="-3" Rank="4" />
              <Competitor CompetitorID="9662" Seed="20" CompetitorNum="4" Bouts="4" Victories="2" TS="17" TR="16" Ind="+1" Rank="3" />
              <Competitor CompetitorID="17361" Seed="29" CompetitorNum="5" Bouts="4" Victories="1" TS="9" TR="17" Ind="-8" Rank="5" />
              <Bout>
                <Competitor CompetitorID="1983" Score="3" Status="D" />
                <Competitor CompetitorID="7284" Score="5" Status="V" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="1983" Score="5" Status="V" />
                <Competitor CompetitorID="7000" Score="2" Status="D" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="1983" Score="3" Status="D" />
                <Competitor CompetitorID="9662" Score="5" Status="V" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="1983" Score="5" Status="V" />
                <Competitor CompetitorID="17361" Score="1" Status="D" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="7284" Score="4" Status="D" />
                <Competitor CompetitorID="7000" Score="5" Status="V" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="7284" Score="5" Status="V" />
                <Competitor CompetitorID="9662" Score="4" Status="D" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="7284" Score="5" Status="V" />
                <Competitor CompetitorID="17361" Score="0" Status="D" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="7000" Score="5" Status="V" />
                <Competitor CompetitorID="9662" Score="3" Status="D" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="7000" Score="2" Status="D" />
                <Competitor CompetitorID="17361" Score="5" Status="V" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="9662" Score="5" Status="V" />
                <Competitor CompetitorID="17361" Score="3" Status="D" />
              </Bout>
            </Pool>
            <Pool Seq="6">
              <Competitor CompetitorID="8252" Seed="6" CompetitorNum="1" Bouts="4" Victories="4" TS="19" TR="9" Ind="+10" Rank="1" />
              <Competitor CompetitorID="1130" Seed="7" CompetitorNum="2" Bouts="4" Victories="2" TS="14" TR="17" Ind="-3" Rank="4" />
              <Competitor CompetitorID="15597" Seed="19" CompetitorNum="3" Bouts="4" Victories="0" TS="9" TR="20" Ind="-11" Rank="5" />
              <Competitor CompetitorID="-1" Seed="18" CompetitorNum="4" Bouts="4" Victories="2" TS="17" TR="14" Ind="+3" Rank="2" />
              <Competitor CompetitorID="13048" Seed="30" CompetitorNum="5" Bouts="4" Victories="2" TS="15" TR="14" Ind="+1" Rank="3" />
              <Bout>
                <Competitor CompetitorID="8252" Score="5" Status="V" />
                <Competitor CompetitorID="1130" Score="3" Status="D" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="8252" Score="5" Status="V" />
                <Competitor CompetitorID="15597" Score="1" Status="D" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="8252" Score="5" Status="V" />
                <Competitor CompetitorID="-1" Score="3" Status="D" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="8252" Score="4" Status="V" />
                <Competitor CompetitorID="13048" Score="2" Status="D" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="1130" Score="5" Status="V" />
                <Competitor CompetitorID="15597" Score="4" Status="D" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="1130" Score="1" Status="D" />
                <Competitor CompetitorID="-1" Score="5" Status="V" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="1130" Score="5" Status="V" />
                <Competitor CompetitorID="13048" Score="3" Status="D" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="15597" Score="3" Status="D" />
                <Competitor CompetitorID="-1" Score="5" Status="V" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="15597" Score="1" Status="D" />
                <Competitor CompetitorID="13048" Score="5" Status="V" />
              </Bout>
              <Bout>
                <Competitor CompetitorID="-1" Score="4" Status="D" />
                <Competitor CompetitorID="13048" Score="5" Status="V" />
              </Bout>
            </Pool>
          </Round>
          <Round Seq="3" Type="DE" Desc="Round #3 - Direct Elimination">
            <Competitor CompetitorID="7268" Seed="1" Status="P">
            </Competitor>
            <Competitor CompetitorID="10776" Seed="2" Status="P">
            </Competitor>
            <Competitor CompetitorID="8252" Seed="3" Status="P">
            </Competitor>
            <Competitor CompetitorID="1536" Seed="4" Status="P">
            </Competitor>
            <Competitor CompetitorID="3014" Seed="5" Status="P">
            </Competitor>
            <Competitor CompetitorID="9201" Seed="6" Status="P">
            </Competitor>
            <Competitor CompetitorID="10644" Seed="7" Status="P">
            </Competitor>
            <Competitor CompetitorID="11108" Seed="8" Status="P">
            </Competitor>
            <Competitor CompetitorID="7284" Seed="9" Status="P">
            </Competitor>
            <Competitor CompetitorID="9862" Seed="10" Status="P">
            </Competitor>
            <Competitor CompetitorID="7276" Seed="11" Status="P">
            </Competitor>
            <Competitor CompetitorID="1983" Seed="12" Status="P">
            </Competitor>
            <Competitor CompetitorID="1130" Seed="13" Status="P">
            </Competitor>
            <Competitor CompetitorID="10762" Seed="14" Status="P">
            </Competitor>
            <Competitor CompetitorID="-2" Seed="15" Status="P">
            </Competitor>
            <Competitor CompetitorID="7000" Seed="16" Status="P">
            </Competitor>
            <Competitor CompetitorID="-1" Seed="17" Status="P">
            </Competitor>
            <Competitor CompetitorID="9662" Seed="18" Status="P">
            </Competitor>
            <Competitor CompetitorID="11337" Seed="19" Status="P">
            </Competitor>
            <Competitor CompetitorID="4510" Seed="20" Status="P">
            </Competitor>
            <Competitor CompetitorID="6999" Seed="21" Status="P">
            </Competitor>
            <Competitor CompetitorID="-3" Seed="22" Status="P">
            </Competitor>
            <Competitor CompetitorID="14945" Seed="23" Status="P">
            </Competitor>
            <Competitor CompetitorID="10842" Seed="24T" Status="P">
            </Competitor>
            <Competitor CompetitorID="13462" Seed="24T" Status="P">
            </Competitor>
            <Competitor CompetitorID="11220" Seed="26" Status="P">
            </Competitor>
            <Competitor CompetitorID="13048" Seed="27" Status="P">
            </Competitor>
            <Competitor CompetitorID="15597" Seed="28" Status="P">
            </Competitor>
            <Competitor CompetitorID="17361" Seed="29" Status="P">
            </Competitor>
            <Competitor CompetitorID="16321" Seed="30" Status="P">
            </Competitor>
            <Competitor CompetitorID="10863" Seed="31" Status="P">
            </Competitor>
            <Competitor CompetitorID="10382" Seed="32" Status="P">
            </Competitor>
            <Competitor CompetitorID="17637" Seed="33" Status="P">
            </Competitor>
            <Competitor CompetitorID="-4" Seed="34" Status="P">
            </Competitor>
            <Table Seq="1" Of="64">
              <Bout Seq="1">
                <Competitor Called="1" CompetitorID="7268" Score="" Status="V">
                </Competitor>
                <Bye Called="2" Seed="64">
                </Bye>
              </Bout>
              <Bout Seq="2">
                <Competitor Called="1" CompetitorID="17637" Score="13" Status="D">
                </Competitor>
                <Competitor Called="2" CompetitorID="10382" Score="15" Status="V">
                </Competitor>
              </Bout>
              <Bout Seq="3">
                <Competitor Called="1" CompetitorID="-1" Score="" Status="V">
                </Competitor>
                <Bye Called="2" Seed="48">
                </Bye>
              </Bout>
              <Bout Seq="4">
                <Bye Called="1" Seed="49">
                </Bye>
                <Competitor Called="2" CompetitorID="7000" Score="" Status="V">
                </Competitor>
              </Bout>
              <Bout Seq="5">
                <Competitor Called="1" CompetitorID="7284" Score="" Status="V">
                </Competitor>
                <Bye Called="2" Seed="56">
                </Bye>
              </Bout>
              <Bout Seq="6">
                <Bye Called="1" Seed="41">
                </Bye>
                <Competitor Called="2" CompetitorID="10842" Score="" Status="V">
                </Competitor>
              </Bout>
              <Bout Seq="7">
                <Competitor Called="1" CompetitorID="13462" Score="" Status="V">
                </Competitor>
                <Bye Called="2" Seed="40">
                </Bye>
              </Bout>
              <Bout Seq="8">
                <Bye Called="1" Seed="57">
                </Bye>
                <Competitor Called="2" CompetitorID="11108" Score="" Status="V">
                </Competitor>
              </Bout>
              <Bout Seq="9">
                <Competitor Called="1" CompetitorID="3014" Score="" Status="V">
                </Competitor>
                <Bye Called="2" Seed="60">
                </Bye>
              </Bout>
              <Bout Seq="10">
                <Bye Called="1" Seed="37">
                </Bye>
                <Competitor Called="2" CompetitorID="15597" Score="" Status="V">
                </Competitor>
              </Bout>
              <Bout Seq="11">
                <Competitor Called="1" CompetitorID="6999" Score="" Status="V">
                </Competitor>
                <Bye Called="2" Seed="44">
                </Bye>
              </Bout>
              <Bout Seq="12">
                <Bye Called="1" Seed="53">
                </Bye>
                <Competitor Called="2" CompetitorID="1983" Score="" Status="V">
                </Competitor>
              </Bout>
              <Bout Seq="13">
                <Competitor Called="1" CompetitorID="1130" Score="" Status="V">
                </Competitor>
                <Bye Called="2" Seed="52">
                </Bye>
              </Bout>
              <Bout Seq="14">
                <Bye Called="1" Seed="45">
                </Bye>
                <Competitor Called="2" CompetitorID="4510" Score="" Status="V">
                </Competitor>
              </Bout>
              <Bout Seq="15">
                <Competitor Called="1" CompetitorID="17361" Score="" Status="V">
                </Competitor>
                <Bye Called="2" Seed="36">
                </Bye>
              </Bout>
              <Bout Seq="16">
                <Bye Called="1" Seed="61">
                </Bye>
                <Competitor Called="2" CompetitorID="1536" Score="" Status="V">
                </Competitor>
              </Bout>
              <Bout Seq="17">
                <Competitor Called="1" CompetitorID="8252" Score="" Status="V">
                </Competitor>
                <Bye Called="2" Seed="62">
                </Bye>
              </Bout>
              <Bout Seq="18">
                <Bye Called="1" Seed="35">
                </Bye>
                <Competitor Called="2" CompetitorID="16321" Score="" Status="V">
                </Competitor>
              </Bout>
              <Bout Seq="19">
                <Competitor Called="1" CompetitorID="11337" Score="" Status="V">
                </Competitor>
                <Bye Called="2" Seed="46">
                </Bye>
              </Bout>
              <Bout Seq="20">
                <Bye Called="1" Seed="51">
                </Bye>
                <Competitor Called="2" CompetitorID="10762" Score="" Status="V">
                </Competitor>
              </Bout>
              <Bout Seq="21">
                <Competitor Called="1" CompetitorID="7276" Score="" Status="V">
                </Competitor>
                <Bye Called="2" Seed="54">
                </Bye>
              </Bout>
              <Bout Seq="22">
                <Bye Called="1" Seed="43">
                </Bye>
                <Competitor Called="2" CompetitorID="-3" Score="" Status="V">
                </Competitor>
              </Bout>
              <Bout Seq="23">
                <Competitor Called="1" CompetitorID="13048" Score="" Status="V">
                </Competitor>
                <Bye Called="2" Seed="38">
                </Bye>
              </Bout>
              <Bout Seq="24">
                <Bye Called="1" Seed="59">
                </Bye>
                <Competitor Called="2" CompetitorID="9201" Score="" Status="V">
                </Competitor>
              </Bout>
              <Bout Seq="25">
                <Competitor Called="1" CompetitorID="10644" Score="" Status="V">
                </Competitor>
                <Bye Called="2" Seed="58">
                </Bye>
              </Bout>
              <Bout Seq="26">
                <Bye Called="1" Seed="39">
                </Bye>
                <Competitor Called="2" CompetitorID="11220" Score="" Status="V">
                </Competitor>
              </Bout>
              <Bout Seq="27">
                <Competitor Called="1" CompetitorID="14945" Score="" Status="V">
                </Competitor>
                <Bye Called="2" Seed="42">
                </Bye>
              </Bout>
              <Bout Seq="28">
                <Bye Called="1" Seed="55">
                </Bye>
                <Competitor Called="2" CompetitorID="9862" Score="" Status="V">
                </Competitor>
              </Bout>
              <Bout Seq="29">
                <Competitor Called="1" CompetitorID="-2" Score="" Status="V">
                </Competitor>
                <Bye Called="2" Seed="50">
                </Bye>
              </Bout>
              <Bout Seq="30">
                <Bye Called="1" Seed="47">
                </Bye>
                <Competitor Called="2" CompetitorID="9662" Score="" Status="V">
                </Competitor>
              </Bout>
              <Bout Seq="31">
                <Competitor Called="1" CompetitorID="10863" Score="15" Status="V">
                </Competitor>
                <Competitor Called="2" CompetitorID="-4" Score="11" Status="D">
                </Competitor>
              </Bout>
              <Bout Seq="32">
                <Bye Called="1" Seed="63">
                </Bye>
                <Competitor Called="2" CompetitorID="10776" Score="" Status="V">
                </Competitor>
              </Bout>
            </Table>
            <Table Seq="2" Of="32">
              <Bout Seq="1">
                <Competitor Called="1" CompetitorID="7268" Score="15" Status="V">
                </Competitor>
                <Competitor Called="2" CompetitorID="10382" Score="4" Status="D">
                </Competitor>
              </Bout>
              <Bout Seq="2">
                <Competitor Called="1" CompetitorID="-1" Score="15" Status="V">
                </Competitor>
                <Competitor Called="2" CompetitorID="7000" Score="14" Status="D">
                </Competitor>
              </Bout>
              <Bout Seq="3">
                <Competitor Called="1" CompetitorID="7284" Score="15" Status="V">
                </Competitor>
                <Competitor Called="2" CompetitorID="10842" Score="10" Status="D">
                </Competitor>
              </Bout>
              <Bout Seq="4">
                <Competitor Called="1" CompetitorID="13462" Score="6" Status="D">
                </Competitor>
                <Competitor Called="2" CompetitorID="11108" Score="15" Status="V">
                </Competitor>
              </Bout>
              <Bout Seq="5">
                <Competitor Called="1" CompetitorID="3014" Score="15" Status="V">
                </Competitor>
                <Competitor Called="2" CompetitorID="15597" Score="5" Status="D">
                </Competitor>
              </Bout>
              <Bout Seq="6">
                <Competitor Called="1" CompetitorID="6999" Score="15" Status="V">
                </Competitor>
                <Competitor Called="2" CompetitorID="1983" Score="11" Status="D">
                </Competitor>
              </Bout>
              <Bout Seq="7">
                <Competitor Called="1" CompetitorID="1130" Score="13" Status="D">
                </Competitor>
                <Competitor Called="2" CompetitorID="4510" Score="15" Status="V">
                </Competitor>
              </Bout>
              <Bout Seq="8">
                <Competitor Called="1" CompetitorID="17361" Score="4" Status="D">
                </Competitor>
                <Competitor Called="2" CompetitorID="1536" Score="15" Status="V">
                </Competitor>
              </Bout>
              <Bout Seq="9">
                <Competitor Called="1" CompetitorID="8252" Score="15" Status="V">
                </Competitor>
                <Competitor Called="2" CompetitorID="16321" Score="3" Status="D">
                </Competitor>
              </Bout>
              <Bout Seq="10">
                <Competitor Called="1" CompetitorID="11337" Score="14" Status="D">
                </Competitor>
                <Competitor Called="2" CompetitorID="10762" Score="15" Status="V">
                </Competitor>
              </Bout>
              <Bout Seq="11">
                <Competitor Called="1" CompetitorID="7276" Score="15" Status="V">
                </Competitor>
                <Competitor Called="2" CompetitorID="-3" Score="9" Status="D">
                </Competitor>
              </Bout>
              <Bout Seq="12">
                <Competitor Called="1" CompetitorID="13048" Score="11" Status="D">
                </Competitor>
                <Competitor Called="2" CompetitorID="9201" Score="15" Status="V">
                </Competitor>
              </Bout>
              <Bout Seq="13">
                <Competitor Called="1" CompetitorID="10644" Score="15" Status="V">
                </Competitor>
                <Competitor Called="2" CompetitorID="11220" Score="9" Status="D">
                </Competitor>
              </Bout>
              <Bout Seq="14">
                <Competitor Called="1" CompetitorID="14945" Score="10" Status="D">
                </Competitor>
                <Competitor Called="2" CompetitorID="9862" Score="15" Status="V">
                </Competitor>
              </Bout>
              <Bout Seq="15">
                <Competitor Called="1" CompetitorID="-2" Score="15" Status="V">
                </Competitor>
                <Competitor Called="2" CompetitorID="9662" Score="14" Status="D">
                </Competitor>
              </Bout>
              <Bout Seq="16">
                <Competitor Called="1" CompetitorID="10863" Score="9" Status="D">
                </Competitor>
                <Competitor Called="2" CompetitorID="10776" Score="15" Status="V">
                </Competitor>
              </Bout>
            </Table>
            <Table Seq="3" Of="16">
              <Bout Seq="1">
                <Competitor Called="1" CompetitorID="7268" Score="11" Status="D">
                </Competitor>
                <Competitor Called="2" CompetitorID="-1" Score="15" Status="V">
                </Competitor>
              </Bout>
              <Bout Seq="2">
                <Competitor Called="1" CompetitorID="7284" Score="15" Status="V">
                </Competitor>
                <Competitor Called="2" CompetitorID="11108" Score="10" Status="D">
                </Competitor>
              </Bout>
              <Bout Seq="3">
                <Competitor Called="1" CompetitorID="3014" Score="15" Status="V">
                </Competitor>
                <Competitor Called="2" CompetitorID="6999" Score="6" Status="D">
                </Competitor>
              </Bout>
              <Bout Seq="4">
                <Competitor Called="1" CompetitorID="4510" Score="11" Status="D">
                </Competitor>
                <Competitor Called="2" CompetitorID="1536" Score="15" Status="V">
                </Competitor>
              </Bout>
              <Bout Seq="5">
                <Competitor Called="1" CompetitorID="8252" Score="15" Status="V">
                </Competitor>
                <Competitor Called="2" CompetitorID="10762" Score="13" Status="D">
                </Competitor>
              </Bout>
              <Bout Seq="6">
                <Competitor Called="1" CompetitorID="7276" Score="14" Status="V">
                </Competitor>
                <Competitor Called="2" CompetitorID="9201" Score="7" Status="D">
                </Competitor>
              </Bout>
              <Bout Seq="7">
                <Competitor Called="1" CompetitorID="10644" Score="11" Status="D">
                </Competitor>
                <Competitor Called="2" CompetitorID="9862" Score="15" Status="V">
                </Competitor>
              </Bout>
              <Bout Seq="8">
                <Competitor Called="1" CompetitorID="-2" Score="10" Status="D">
                </Competitor>
                <Competitor Called="2" CompetitorID="10776" Score="15" Status="V">
                </Competitor>
              </Bout>
            </Table>
            <Table Seq="4" Of="8">
              <Bout Seq="1">
                <Competitor Called="1" CompetitorID="-1" Score="7" Status="D">
                </Competitor>
                <Competitor Called="2" CompetitorID="7284" Score="15" Status="V">
                </Competitor>
              </Bout>
              <Bout Seq="2">
                <Competitor Called="1" CompetitorID="3014" Score="15" Status="V">
                </Competitor>
                <Competitor Called="2" CompetitorID="1536" Score="7" Status="D">
                </Competitor>
              </Bout>
              <Bout Seq="3">
                <Competitor Called="1" CompetitorID="8252" Score="14" Status="D">
                </Competitor>
                <Competitor Called="2" CompetitorID="7276" Score="15" Status="V">
                </Competitor>
              </Bout>
              <Bout Seq="4">
                <Competitor Called="1" CompetitorID="9862" Score="5" Status="D">
                </Competitor>
                <Competitor Called="2" CompetitorID="10776" Score="15" Status="V">
                </Competitor>
              </Bout>
            </Table>
            <Table Seq="5" Of="4">
              <Bout Seq="1">
                <Competitor Called="1" CompetitorID="7284" Score="15" Status="V">
                </Competitor>
                <Competitor Called="2" CompetitorID="3014" Score="12" Status="D">
                </Competitor>
              </Bout>
              <Bout Seq="2">
                <Competitor Called="1" CompetitorID="7276" Score="15" Status="V">
                </Competitor>
                <Competitor Called="2" CompetitorID="10776" Score="9" Status="D">
                </Competitor>
              </Bout>
            </Table>
            <Table Seq="6" Of="2">
              <Bout Seq="1">
                <Competitor Called="1" CompetitorID="7284" Score="8" Status="D">
                </Competitor>
                <Competitor Called="2" CompetitorID="7276" Score="15" Status="V">
                </Competitor>
              </Bout>
            </Table>
          </Round>
        </RoundResults>
      </Event>
    </Tournament>

    <ClubDatabase>
      <Club ClubID="157" DivisionID="29" Name="Bucks County Academy of Fencing" Abbreviation="BCAF" City="Lambertville" State="NJ" />
      <Club ClubID="676" DivisionID="29" Name="Atlantic Fencing Club" Abbreviation="ATLANTIC" City="Colts Neck" State="NJ" />

}

# 
# DealWithRound - load and print the data for a given round of pools
#

proc XDealWithRound { out round } {
	global tour_de_poules PrintStyle

	# PrintRoundInfo $round

	# load and print the individual pools
	array set PoolInfo $tour_de_poules($round)
	for { set pool 1 } { $pool <= $PoolInfo(nombre_poules) } { incr pool } {
		global Pool

		# puts "Call Pool_LoadData $round $pool"

		# puts $Pool($pool)
		if { [info procs Pool_Print_$PrintStyle] != "" } {
			Pool_Print_$PrintStyle $out $round $pool
		} else {
			Pool_Print $out $round $pool
		}
	}
}


#####################################################

#
# Print rankings at the end of a round of pools
#

proc xPrintEndOfRound_text { out _data title } {
  upvar $_data data
  if { "$title" != "" } {
    puts $out "=== $title ==="
  } else {
    puts $out "=== Ranking after this round of pools ==="
  }
  foreach fi [lsort -integer [array names $_data]] {
	array set fd $data($fi)

	puts $out "$fd(rank)|[FencerName $fd(fnumber)]|[FencerClub $fd(fnumber)]|$fd(wins)/$fd(bouts)|[format {%.3f} [expr 1.0 * $fd(wins) / $fd(bouts)]]|$fd(ts)|$fd(tr)|[expr $fd(ts) - $fd(tr)]"
  }
}

proc _compareRank { a b } {
   array set fd $data($fi)
}


proc xPrintEndOfRound_HTML { out _data title } {
  upvar $_data data
  if { "$title" != "" } {
    puts $out "<p class=\"result_section\">$title</p>"
  }

    # provide an index
    puts $out {<table border="0"><tr><td>}

  puts $out {<table class="fencer_list" cellspacing="0">}
  puts $out {<caption>By rank</caption>}
  puts $out "<tr>"
  puts -nonewline $out "<th>Rank</th>"
  puts -nonewline $out "<th width=\"250\">Name</th>"
  puts -nonewline $out "<th>Club</th>"
  puts -nonewline $out "<th>Wins/Bouts</th>"
  puts -nonewline $out "<th>Pct.</th>"
  puts -nonewline $out "<th>TS</th>"
  puts -nonewline $out "<th>TR</th>"
  puts -nonewline $out "<th>Ind.</th>"
  puts $out "</tr>"
  foreach fi [lsort -integer [array names $_data]] {
	array set fd $data($fi)

	puts -nonewline $out "<tr>"
	puts -nonewline $out "<td class=\"index\">$fd(rank)</td>"
	puts -nonewline $out "<td>[FencerName $fd(fnumber)]</td>"
	puts -nonewline $out "<td>[FencerClub $fd(fnumber)]</td>"
	puts -nonewline $out "<td class=\"numb\">$fd(wins)/$fd(bouts)</td>"
	puts -nonewline $out "<td class=\"numb\">[format {%.3f} [expr 1.0 * $fd(wins) / $fd(bouts)]]</td>"
	puts -nonewline $out "<td class=\"numb\">$fd(ts)</td>"
	puts -nonewline $out "<td class=\"numb\">$fd(tr)</td>"
	puts -nonewline $out "<td class=\"numb\">[expr $fd(ts) - $fd(tr)]</td>"
	puts $out "</tr>"
  }
  puts $out "</table>"

  # provide an index
    puts $out {</td><td width="25"></td><td>}
    PrintRanksByName_HTML $out
    puts $out {</td></tr></table>}
}


proc xPrintRanksByName_HTML { out } {
  global Fencer

  puts $out {<table class="fencer_list" cellspacing="0">}
  puts $out {<caption>By name</caption>}
  puts -nonewline $out {<tr>}
  puts -nonewline $out {<th colspan="1" width=\"200\">Fencer</th>}
  puts -nonewline $out {<th>&nbsp;Rank&nbsp;</th>}
  puts -nonewline $out {<th>Pct.</th>}
  puts -nonewline $out {<th>Ind.</th>}
  puts $out {</tr>}
  set pos 0
  foreach i [FencersByName] {
        array set x $Fencer($i)
        incr pos

	if { $x(isPresent) == 0 } continue

        puts -nonewline $out {<tr>}
        puts -nonewline $out "<td>$x(last_name), $x(first_name)</td>"
	if { [info exists x(pool_rank) ] } {
          puts -nonewline $out "<td class=\"index\">$x(pool_rank)</td>"
	  set pct [expr 1.0 * $x(pool_wins) / $x(pool_bouts)]
	  puts -nonewline $out "<td class=\"numb\">[format {%.3f} $pct]</td>"
	  set ind [expr $x(pool_ts) - $x(pool_tr)]
          puts -nonewline $out "<td class=\"numb\">$ind</td>"
	} else {
	  puts -nonewline $out "<td>???</td>"
	  puts -nonewline $out "<td>???</td>"
	  puts -nonewline $out "<td>???</td>"
	}
        puts $out {</tr>}
  }
  puts $out {</table>}
}


proc xPrintEndOfRound { out _data title } {
  global PrintStyle
  upvar $_data data
  if { [ info proc "PrintEndOfRound_$PrintStyle" ] != "" } {
	PrintEndOfRound_$PrintStyle $out data $title
  } else {
	PrintEndOfRound_text $out data $title
  }
}


proc xPrintRoundInfo { round } {
  global tour_de_poules PrintStyle

  puts "=== Pool Info ==="
  array set x $tour_de_poules($round)

  lineBreak_$PrintStyle
  puts "$x(nombre_poules) pools"
  lineBreak_$PrintStyle
  puts "$x(entites_exemptees) exemptions"
  lineBreak_$PrintStyle
  puts "$x(entites_par_poule) fencers / pool"
  lineBreak_$PrintStyle
  puts "$x(nombre_touches_poules) touches per bout"

  lineBreak_$PrintStyle
  puts "$x(qualifies_par_poule) quaifiers / pool"
  lineBreak_$PrintStyle
  puts "$x(qualifies_indice) qualifies_indice"
  lineBreak_$PrintStyle
  puts "$x(qualifies) qualify"
  lineBreak_$PrintStyle
  puts "$x(entites_fin) fencers at end of pools"
  
  lineBreak_$PrintStyle
  puts "entities_depart: $x(entites_depart)"
  lineBreak_$PrintStyle
  puts "$x(entites_dans_poules) fencers"
  lineBreak_$PrintStyle
  puts "critere_decal_1: $x(critere_decal_1)"
  
  lineBreak_$PrintStyle
  puts "critere_placement: $x(critere_placement)"
  lineBreak_$PrintStyle
  puts "seed by $x(critere)"
}





proc XPool_Print_HTML { out round pi } {
  global Pool
  array set p $Pool($pi)

  #DBG puts "Printing Round $round, Pool $pi"
  # parray p

  puts $out "<p class=\"result_section\">Round $round, Pool $pi</p>"
  if { [ info exists p(piste_no) ] } {
    puts $out "Strip: $p(piste_no)"
  }

  # the list of fencers is in pool order
  set flist $p(les_tir_feuille)

  # puts $out "tir_cons = $p(les_tir_cons)"
  set nBouts [llength $p(les_tir_cons)]

  # reorganize the scores data by fencer
  if { ! [ info exists p(scores) ] } {
    foreach fi $flist {
       set rank ""
       set fencerIndex $fi
       set bouts 0
       set wins 0
       set ts  ""
       set tr  ""
       set scores($fencerIndex) [list $rank $bouts $wins $ts $tr]
       #DBG puts $out "$fencerIndex: $s"
    }
  } else {
    # [scores ((e 7 17 6 1 16 29) (e 1 15 6 5 29 15) (e 3 20 6 3 24 22) ....
    foreach s $p(scores) {
       set rank [lindex $s 1]
       set fencerIndex [lindex $s 2]
       set bouts [lindex $s 3]
       set wins [lindex $s 4]
       set ts [lindex $s 5]
       set tr [lindex $s 6]
       set scores($fencerIndex) [list $rank $bouts $wins $ts $tr]
       #DBG puts $out "$fencerIndex: $s"
    }
  }
 
  # print the fencers
  puts $out {<table class="fencer_list" cellspacing="0" border="1">}
  puts -nonewline $out {<tr height="25">}
  puts -nonewline $out "<th id=\"index\">#</th>"
  puts -nonewline $out "<th width=\"250\">Fencer</th>"
  # puts -nonewline $out "<th width=\"70\">Club</th>"
  puts -nonewline $out "<th colspan=\"$nBouts\">Bouts</th>"
  puts -nonewline $out "<th>wins/bouts</th>"
  puts -nonewline $out "<th>TS</th>"
  puts -nonewline $out "<th>TR</th>"
  puts -nonewline $out "<th>Ind.</th>"
  puts -nonewline $out "<th>Rank</th>"
  puts -nonewline $out {</tr>}
  set flist $p(les_tir_feuille)
  set gi 0
  foreach fi $flist {

     # get the bout list for this fencer
     if { [info exists p(grille)] } {
       # {*** {}} {d 1} {v 5} {d 1} {d 4} {d 3} {d 2}
       set boutsForThisFencer [lindex $p(grille) $gi]
     } else {
       set boutsForThisFencer {}
       for { set i 0 } { $i < $nBouts } { incr i } {
         if { $i == $gi } {
           lappend boutsForThisFencer [list "***" x]
         } else {
           lappend boutsForThisFencer [list x x]
         }
       }
     }
     incr gi

     set rank [lindex $scores($fi) 0]
     set bouts [lindex $scores($fi) 1]
     set wins [lindex $scores($fi) 2]
     set total_ts [lindex $scores($fi) 3]
     set total_tr [lindex $scores($fi) 4]

     puts -nonewline $out {<tr class="gridrow">}
     # puts -nonewline $out "<td>[format {%2d} $fi]</td>"
     puts -nonewline $out "<td class=\"index\">[format {%2d} $gi]</td>"
     puts -nonewline $out "<td>[FencerName $fi]</td>"
     # puts -nonewline $out "<td>[FencerClub $fi]</td>"

     foreach bout $boutsForThisFencer {
       set x [lindex $bout 0]
       set ts [lindex $bout 1]
       puts -nonewline $out "<td width=\"25\" "
       if { $x == "***" } {
         puts -nonewline $out " class=\"gridblack\">&nbsp;"
       } elseif { $x == "v" } {
         puts -nonewline $out " class=\"gridcell\"> V "
       } elseif { $x == "w" } {
         puts -nonewline $out " class=\"gridcell\"> V$ts "
       } elseif { $x == "x" } {
         puts -nonewline $out " class=\"gridcell\">&nbsp;"
       } else {
         puts -nonewline $out " class=\"gridcell\"> $ts "
       }
       puts -nonewline $out {</td>}
     }
     if { $total_ts == "" } {
       set total_ts "&nbsp;"
       set total_tr "&nbsp;"
       set ind "&nbsp;"
       set rank "&nbsp;"
     } else {
       set ind [expr $total_ts - $total_tr]
     }
     if { $bouts == 0 } {
       puts -nonewline $out "<td class=\"numb\">&nbsp;</td>"
     } else {
       puts -nonewline $out "<td class=\"numb\">$wins/$bouts</td>"
     }
     puts -nonewline $out "<td class=\"numb\">$total_ts</td>"
     puts -nonewline $out "<td class=\"numb\">$total_tr</td>"
     puts -nonewline $out "<td class=\"numb\">$ind</td>"
     puts -nonewline $out "<td class=\"numb\">$rank</td>"
     puts $out {</tr>}
  }
  puts $out {</table>}
}



