# fencing_print_comp.tcl - Print overall competition information
#			and initial fencer field lists
#
# Copyright 2006, Tony Aiuto
#
# Author: Tony Aiuto, tony.aiuto@gmail.com
#
# public methods
#	PrintCompetitionInfo_HTML out
#	PrintField_text out
#	PrintField_HTML
#	PrintFencers_text out round title
#	PrintFencers_HTML out round title
#	PrintFinal_HTML out
#	PrintUSFAClassChanges_PS out



proc PrintCompetitionInfo_HTML { out } {
    global Competition
    global timeStampOutput

    if { [info exists timeStampOutput] && $timeStampOutput != 0 } {
	puts $out "<p class=\"editorial\">[clock format [clock seconds] -format {%A, %d-%b-%Y %H:%M:%S %p}]</p>"
    }

    puts $out "<p class=\"section\">$Competition(title_long)</p>"
    puts $out "$Competition(title1)"
    puts $out "<br/>$Competition(title2)"
    puts $out "<br/>$Competition(title3)"
    puts $out "<br/>$Competition(title4)"
    puts $out "<br/>Date: $Competition(date)"

    puts $out "<br/>Federation: $Competition(federation)"
    if { [info exists Competition(organizer)] } {
      puts $out "<br/>Organizer: $Competition(organizer)"
    }
    puts $out "<br/>Category: $Competition(category)"
    puts $out "<br/>Sex: $Competition(sex)"
    puts $out "<br/>Weapon: $Competition(weapon)"

    puts $out "<br/>$Competition(nFencers) fencers"
    if { [info exists Competition(fencer_classifications)] } {
	array set ranks $Competition(fencer_classifications)
	foreach a [lsort [array names ranks]] {
	    if { $ranks($a) != 0 } {
		puts $out " - $ranks($a) $a's"
	    }
	}
    }
    # TODO - a vs. an based on vowel in class
    set tmp $Competition(classification) 
    if { $tmp != "" } {
	puts $out "<br/>Could be [isVowel [string range $tmp 0 0] "an" "a"] $tmp competition"
    }
}



#
# Show the initial field of fencers
#

proc PrintField_text { out } {
  puts $out "=== All Fencers ==="
  global Fencer
  foreach i [FencersByName] {
	array set x $Fencer($i)
     	puts $out "$x(last_name), $x(first_name), $x(cle), [ClubName $x(club)], $x(birth_year), $x(usfa_rank)]"
  }
}

proc PrintField_HTML { out } {
  global Fencer

  puts $out {<p class="result_section"><a name="fencers">Fencers</a></p>}
  puts $out {<table class="fencer_list" cellspacing="0">}
  puts -nonewline $out {<tr>}
  puts -nonewline $out {<th>#</th>}
  puts -nonewline $out {<th colspan="2" width=\"250\">Fencer</th>}
  puts -nonewline $out {<th>Club</th>}
  puts -nonewline $out {<th>Birth<br/>Year</th>}
  puts -nonewline $out {<th class="usfaclass">USFA<br/>Class.</th>}
  puts $out {</tr>}
  set pos 0
  foreach i [FencersByName] {
	array set x $Fencer($i)
	incr pos
  	puts -nonewline $out {<tr>}
     	HTML_table_cell $out $pos "index"
     	HTML_table_cell $out $x(last_name) ""
     	HTML_table_cell $out $x(first_name) ""
     	# HTML_table_cell $out $x(index) ""
	HTML_table_cell $out [ClubName $x(club)] ""
	HTML_table_cell $out $x(birth_year) ""
	HTML_table_cell $out $x(usfa_rank) "rank"

  	puts $out {</tr>}
  }
  puts $out {</table>}
}


#
# Show the current Fencer list 
#

proc PrintFencers_text { out round title } {
  puts $out "=== Fencers in this round $round of pools ==="
  global Fencer FLIST
  for { set i 0 } { $i < [llength $FLIST($round)]} { incr i } {
  	set fnumber [lindex $FLIST($round) $i]
	array set x $Fencer($fnumber)
     	puts $out "$x(last_name), $x(first_name), $x(cle), [ClubName $x(club)], $x(birth_year), $x(usfa_rank)"
  }
}

proc PrintFencers_HTML { out round title } {
  global Competition
  if { "$title" != "" } {
    puts $out "<p class=\"result_section\">$title</p>"
  } else {
    puts $out "<p class=\"result_section\">Fencers in round $round</p>"
  }
  puts $out {<table class="fencer_list" cellspacing="0">}
  puts -nonewline $out {<tr>}
  puts -nonewline $out {<th>Rank</th>}
  puts -nonewline $out {<th width="250">Fencer</th>}
  puts -nonewline $out {<th>Club</th>}
  puts -nonewline $out {<th>Birth<br/>Year</th>}
  puts -nonewline $out {<th class="usfaclass">USFA<br/>Class.</th>}
  puts $out {</tr>}
  global Fencer
  global FLIST
  for { set i 0 } { $i < [llength $FLIST($round)]} { incr i } {
  	set fnumber [lindex $FLIST($round) $i]
	array set x $Fencer($fnumber)
  	puts -nonewline $out {<tr>}
     	HTML_table_cell $out [expr $i + 1] "index"
     	HTML_table_cell $out [FencerName $fnumber] ""
	HTML_table_cell $out [ClubName $x(club)] ""
	HTML_table_cell $out $x(birth_year) ""
	HTML_table_cell $out $x(usfa_rank) "rank"
  	puts $out {</tr>}
  }
  puts $out {</table>}
}


#
# PrintFinal_HTML - print final rankings in HTML
# these are calculated as a side effect of printing the tables
#
proc PrintFinal_HTML { out } {
  global Fencer
  global Competition Award

  puts $out {<!--begin final ranking-->}
  puts $out {<a name="final">}

  set nQualify [HowManyQualify]
  set NQ3 [HowManyQualifyD3InCombinedD23]
  # puts $out "<br/>NQ3 = $NQ3"

  if { $Competition(haveFinal) != 0 } {
    puts $out "<p class=\"result_section\"><a name=\"final\">Final Rankings</a></p>"
  } else {
    puts $out "<p class=\"result_section\">Tentative Final Rankings</p>"
  }
  puts $out "$Competition(classification) competition"
  if { $nQualify > 0 } {
	puts $out "<br/>$Competition(nFencers) fencers, $nQualify qualifiy"
  }
  if { $Competition(isQualifier) == "d23" } {
	puts $out "<br/>excluding C's and above, $NQ3 qualifiy for Division III"
  }

  puts $out {<table class="fencer_list" cellspacing="0">}
  puts -nonewline $out {<tr>}
  puts -nonewline $out {<th>Rank</th>}
  puts -nonewline $out {<th colspan="1" width="250">Fencer</th>}
  puts -nonewline $out {<th>Club</th>}
  puts -nonewline $out {<th class="usfaclass">USFA<br/>Class.</th>}
  puts -nonewline $out {<th class="usfaclass">New<br/>Class.</th>}
  if { $nQualify > 0 } {
    puts -nonewline $out {<th class="rank">Qual.</th>}
    set qNumber 1
    set q3Number 1
  }
  puts $out {</tr>}

  foreach FI [FencersByRank] {
    if { $FI == "nobody" } {
      continue
    }

    array set x $Fencer($FI)
    if { $x(isPresent) == 0 } continue

    set qualText ""
    if { $nQualify > 0 } {
      set orank $x(usfa_rank)
      set oClass [string range $orank 0 0]
      if { $oClass == "" } {
	set oClass "U"
      }

      if { [info exists x(auto_qual)] && $x(auto_qual) == "auto" } {
	set qualText "Auto"
      } elseif { $qNumber <= $nQualify } {
	set qualText "Q$qNumber"
	if { $Competition(isQualifier) == "d23" } {
	  set qualText "Div II Q$qNumber"
	  if { [string compare $oClass "D"] >= 0 } {
	    if { $q3Number <= $NQ3 } {
		set qualText "Div II Q$qNumber - Div III Q$q3Number"
		incr q3Number
	    }
	  }
	}
        incr qNumber
      } elseif { $Competition(isQualifier) == "d23" } {
	if { $q3Number <= $NQ3 } {
	  if { [string compare $oClass "D"] >= 0 } {
	    set qualText "Div III - Q$q3Number"
            incr q3Number
	  }
	}
      }
    }

    set rankI $x(final_rank)
    if { $rankI == 99999 } {
	set rankI "-"
    }

    set htmlclass ""
    if { $rankI == 1 } {
	set htmlclass "gold"
    } elseif { $rankI == 2 } {
	set htmlclass "silver"
    } elseif { $rankI == 3 } {
	set htmlclass "bronze"
    }
    if { $qualText != "" } {
	append htmlclass "qualifier"
    }

    if { $htmlclass == "" } {
      puts -nonewline $out {<tr>}
    } else {
      puts -nonewline $out "<tr class=\"$htmlclass\">"
    }
    HTML_table_cell $out $rankI "index"
    HTML_table_cell $out [FencerName $FI] ""
    HTML_table_cell $out [ClubName $x(club)] ""

    # print their USFA class and any change in class
    set orank $x(usfa_rank)
    set oClass [string range $orank 0 0]
    HTML_table_cell $out $orank "usfaclass"
    set nrank "&nbsp;"

    if { [info exists Award($rankI)] } {
        set t "$Award($rankI)$Competition(year)"

	# we only assign a new class if it changes up
	# or if it stays the same but is a different year
	# 
	set nClass [string range $t 0 0]
	if { [string compare "$oClass" "$nClass"] >= 0 || $oClass == "" } {
	   if { $oClass != $nClass || $orank != $t } {
	       set nrank $t
	   }
	}
    }
    HTML_table_cell $out $nrank "usfaclass"

    if { $nQualify > 0 } {
      if { $qualText == "" } { set qualText "&nbsp;" }
      puts -nonewline $out "<td class=\"QN\">$qualText</td>"
    }
    puts $out {</tr>}
  }
  puts $out {</table>}

  puts $out {<!--end final ranking-->}
}




#########################################################################
#
# PrintUSFAClassChanges_PS - generate the paper to send to the USFA
# for class changes that occur during a competition
#


proc PrintUSFAClassChanges_PS { out } {
    global Competition

    set today [clock format [clock seconds] -format {%d-%b-%Y}]

    startPage_PS $out

    puts $out "/f1 /Bitstream-Charter findfont 1 scalefont def"
    puts $out "120 setFontSize"
    puts $out "f1 fontSize scalefont setfont"

    puts $out {

% ruleToEOL - draw rule to end of line
/ruleToEOL {
   /hpos currentpoint pop def		% save position
   0 -20 rmoveto			% move a little below the baseline
   inch 8.5 mul right_margin sub hpos sub	% distance from hpos to margin
   4 setlinewidth
   0 rlineto stroke 
   hpos vpos moveto			% restore position
} def

}

    puts $out "nl (Name of the tournament:) show"
    puts $out " fontSize 0 rmoveto"
    puts $out " ruleToEOL"
    puts $out " fontSize 0 rmoveto"
    puts $out " ($Competition(title_long)) show"

    puts $out "nl (Location of the tournament:) show"
    puts $out " fontSize 0 rmoveto"
    puts $out " ruleToEOL"
    puts $out " fontSize 0 rmoveto"
    puts $out " ($Competition(title4)) show"

    puts $out "nl (Host USFA Organization:) show"
    if { [info exists Competition(organizer)] } {
      puts $out " fontSize 0 rmoveto"
      puts $out " ruleToEOL"
      puts $out " fontSize 0 rmoveto"
      puts $out " ($Competition(organizer)) show"
    }

    puts $out "nl (Date of the tournament:) show"
    puts $out " fontSize 0 rmoveto"
    puts $out " ($Competition(date)) show"
    puts $out " inch 5 mul vpos moveto"
    puts $out " (Date Submitted:) show"
    puts $out " fontSize 0 rmoveto"
    puts $out " ($today) show"

    puts $out "nl (Submitted By:) show"
    puts $out " fontSize 0 rmoveto"
    puts $out " ruleToEOL"

    puts $out "nl (Division:) show"
    puts $out " fontSize 0 rmoveto"
    puts $out " ruleToEOL"
    puts $out " fontSize 0 rmoveto"
    puts $out " ($Competition(federation)) show"

if { 0 } {
    puts $out "<br/>Category: $Competition(category)"
    puts $out "<br/>Sex: $Competition(sex)"
    puts $out "<br/>Weapon: $Competition(weapon)"

    puts $out "<br/>$Competition(nFencers) fencers"
    if { [info exists Competition(fencer_classifications)] } {
	array set ranks $Competition(fencer_classifications)
	foreach a [lsort [array names ranks]] {
	    if { $ranks($a) != 0 } {
		puts $out " - $ranks($a) $a's"
	    }
	}
    }
    # TODO - a vs. an based on vowel in class
    set tmp $Competition(classification) 
    if { $tmp != "" } {
	puts $out "<br/>Could be [isVowel [string range $tmp 0 0] "an" "a"] $tmp competition"
    }
 }

    endPage_PS $out
}

