# fencing_usfa - USFA related methods
#
# Copyright 2006, Tony Aiuto
#
# Author: Tony Aiuto, tony.aiuto@gmail.com
#
# Public Methods
#	HowManyQualify
#	HowManyQualifyD3InCombinedD23
#	CalculateCompetitionGroup
#		sets Competition(classification)
#	GetUSFAClass
#	CategorizeCompetition_USFA
#
# Requirements
#	global Fencer Competition
#


#############################################################
#
# Definition of Competition Groups
#
# Name, size, required, finish in top 8, finish in top 12, awards
# note that the finish in top 12 INCLUDES the top 8.  This is just
# to make checking easier.   We can just check the top 8 and
# top 12 requirements separately
#
# THIS MUST BE SORTED IN FROM E-A and 1-N within that


set Groups {
  {E1 6  {}		{}		{} 	{E 1}}
  {D1 15 {}		{}		{} 	{D 1 E 3} }
  {C1 15 {C 2 D 2 E 2}	{C 2 D 2}	{} 	{C 1 D 3 E 4} }
  {C2 25 {D 4 E 4}	{D 4}		{} 	{C 1 D 3 E 4} }
  {C3 64 {D 24 E 12} 	{D 4}		{D 4 E 4} {C 4 D 4 E 8} }
  {B1 15 {B 2 C 2 D 2}	{B 2 C 2}	{} 	{B 1 C 3 D 2 E 2} }
  {B2 25 {B 2 C 2 D 2}	{B 2 C 2}	{} 	{B 1 C 3 D 4 E 4} }
  {B3 64 {C 24 D 12}	{C 4}		{C 4 D 4} {B 4 C 4 D 8 E 16} }

  {A1 15 {A 2 B 2 C 2}	{A 2 B 2}	{} 	  {A 1 B 3 C 2 D 2} }
  {A2 25 {A 2 B 2 C 2}	{A 2 B 2}	{} 	  {A 1 B 3 C 4 D 2 E 2} }
  {A3 64 {B 24 C 12}	{B 4}		{B 4 C 4} {A 4 B 4 C 8 D 8 E 8} }
  {A4 64 {A 12 B 12 C 12}  {A 4}	{A 4 B 4} {A 8 B 8 C 8 D 8 E 16} }
}

set TestGroups {
  {Z1 10 {E 3}		{E 2}		{} 	{D 3 E 1 Q 1}}
}

#
#############################################################


#
# Calculate how many people qualify, according to USFA tables 2-2/3
#
proc HowManyQualify { } {
  global Competition

  if { ! [info exists Competition(minQualify)] } {
    set Competition(minQualify) 3

    # TODO - hueristically check for name Sr Sectional and make it 8
  }

  if { $Competition(isQualifier) == "" } {
	return 0
  }
  # 25% (rounded up to next whole #) qualify
  set nQual [expr ( $Competition(nFencers) + 3 ) / 4]
  if { $nQual < 3 } { set nQual 3 }
  if { $nQual < $Competition(minQualify) } { set nQual $Competition(minQualify) }

  return $nQual
}


#
# Calculate how many people qualify, according to USFA tables 2-2/3
#
proc HowManyQualifyD3InCombinedD23 { } {
  global Competition

  if { $Competition(isQualifier) == "" } {
	return 0
  }
  # 25% (rounded up to next whole #) qualify
  set nFence $Competition(nFencers)
  # now subtract out the number of A, B, and C fencers
  array set classcounts $Competition(fencer_classifications)
  set nFence [expr $nFence - $classcounts(A)]
  set nFence [expr $nFence - $classcounts(B)]
  set nFence [expr $nFence - $classcounts(C)]
  set nQual [expr ( $nFence + 3 ) / 4]
  if { $nQual < 3 } { set nQual 3 }
  if { $nQual < $Competition(minQualify) } { set nQual $Competition(minQualify) }

  return $nQual
}


# calculate the USFA competition group 
# if called when Competition(haveFinal) is set,
# then it calculates the actual rank achieved
#
# Side effects:
# sets global Competition(classification)
# if we "haveFinal" -> awards new classifications into global Award table
# 

proc CalculateCompetitionGroup { } {
    global Groups
    global Fencer
    global Competition

    if { $Competition(federation) != "USFA" } {
	set Competition(classification) ""
	return
    }

    foreach uclass {A B C D E U} {
	set competitors($uclass) 0
	#set $uclass 0
	#set ${uclass}_8 0
	#set ${uclass}_12 0
    }

    # get initial classifications
    #
    set nComps 0
    foreach FI [array names Fencer ] {
	array set x $Fencer($FI)
        set rank $x(usfa_rank)
	incr nComps
        set uclass [string toupper [string range $rank 0 0]]
        if { [info exists competitors($uclass)] } {
            incr competitors($uclass)
	    # incr $uclass
	} else {
            set competitors($uclass) 1
	    # set $uclass 1
	}
    }
    set Competition(fencer_classifications) [array get competitors]
    # parray competitors

    if { $Competition(haveFinal) != 0 } {
      foreach uclass {A B C D E U} {
	set top8($uclass) 0
	set top12($uclass) 0
      }

      foreach FI [FencersByRank] {
	array set x $Fencer($FI)
	set rankI $x(final_rank)
    	# if { $FI == "nobody" } continue

        set rank $x(usfa_rank)
        set uclass [string toupper [string range $rank 0 0]]
        if { $rankI <= 8 } {
            if { [info exists top8($uclass)] } {
                incr top8($uclass)
	        # incr ${uclass}_8
	    } else {
                set top8($uclass) 1
	        # set ${uclass}_8 1
	    }
	}
        if { $rankI <= 12 } {
            if { [info exists top12($uclass)] } {
                incr top12($uclass)
	        # incr ${uclass}_12
	    } else {
                set top12($uclass) 1
	        # set ${uclass}_12 1
	    }
	}
      }
      # parray top8
      # parray top12
    }

    # sample: {C1 15 {C 2 D 2 E 2} {8 C 2 D 2} {C D D D E E E E} }
    set lastgC ""
    set lastgN 0
    set class1 ""
    set class2 ""
    foreach group $Groups {
	set gName [lindex $group 0]
	  set gC [string range $gName 0 0]
	  set gN [string range $gName 1 1]
	set gComps [lindex $group 1]
	set gClassIn [lindex $group 2]
	set gClassFinish8 [lindex $group 3]
	set gClassFinish12 [lindex $group 4]
	set gAward [lindex $group 5]


	if { $Competition(isYouth) == 1 && ($gName == "E1" || $gName == "D1")} {
	  continue
	}

        if { $nComps < $gComps }  continue
	if { [_checkRequired competitors $gClassIn] == 0 } continue
        if { $Competition(haveFinal) != 0 } {
	  if { [_checkRequired top8 $gClassFinish8] == 0 } continue
	  if { [_checkRequired top12 $gClassFinish12] == 0 } continue
	}

	if { $gC == $lastgC } {
	    # this is a bigger size at the same level
	    # we should replace the current competition
	    set class1 $gName
	    set lastgN $gN
        } elseif { $lastgC == "" } {
	    # this is the first time through
	    set class1 $gName
	    set lastgC $gC
	    set lastgN $gN
	} else {
	    # this is a higher level
	    # if this is B3 -> A1 we keep both
	    # if this is B1 -> A1, then we replace with A1
	    if { $lastgN > $gN } {
	    	set class2 $class1
	    }
	    set class1 $gName
	    set lastgC $gC
	    set lastgN $gN
	}
        # puts "<br/>Class is $class1 / $class2"

        if { $Competition(haveFinal) != 0 } {
	  # assisgn awards
          global Award
	  set i 1
	  # puts "give awards - $gAward"
	  while { [llength $gAward] > 0 } {
	    set class [lindex $gAward 0]
	    set count [lindex $gAward 1]
	    set gAward [lrange $gAward 2 end]
	    while { $count > 0 } {
		# puts "set Award($i) - $class"
		set Award($i) $class
		incr count -1
		incr i
	    }
	  }
	}
    }

    if { $class1 == "" } { set class1 "NR" }
    if { $class2 == "" } {
      set Competition(classification) "$class1"
    } else {
      set Competition(classification) "$class1/$class2"
    }
}

# internal to CalculuateGroup
proc _checkRequired { _comps _req } {
    upvar $_comps comps

    array set req $_req

    # how many people at higher classes are left over
    set leftOver 0
    foreach class {A B C D E} {
	set want 0
	if { [info exists req($class)] } {
	    set want $req($class)
 	}
	#puts "<br/>Check $class ... got $comps($class) + $leftOver, want $want"
	set avail [expr $comps($class) - $want]
	if { $avail + $leftOver < 0 } {
	    return 0
	}
	incr leftOver $avail
    }
    return 1
}

#
# GetUSFAClass - check if a string is a USFA class and returns the
# cannonical form.  return empty string if not
#
proc GetUSFAClass { s } {
	# LI Division hack ....
	# sometimes they go back and modify the license string
	# to show the change in class. e.g "U------>E06"
	# that way they can print a nice table at the end.  Agggh!
	regsub -- { *--*>.*$} $s {} s
	regsub -- { *==*>.*$} $s {} s
	# end LIhack

	set s [string toupper $s]
	if { "$s" == "U" } {
		return "$s"
	}
	if { [regexp {^[A-E][0-9][0-9]$} $s] } {
		return "$s"
	}
	if { [regexp {^[A-E]20[0-9][0-9]$} $s] } {
		regsub "20" $s "" s
		return $s
	}
	return ""
}



#
# Apply some hueristics to help categorize the competition
#
#
proc CategorizeCompetition_USFA { } {
    global Competition

    # check the titles for the word "qualifier" and turn this into one
    # unless it was set from the command line

    if { ![info exists Competition(isQualifier)] || $Competition(isQualifier) == "" } {
      if { [regexp -nocase qualifier $Competition(title1)] ||
	   [regexp -nocase qualifier $Competition(title2)] ||
	   [regexp -nocase qualifier $Competition(title3)] ||
	   [regexp -nocase qualifier $Competition(title4)] } {
	set Competition(isQualifier) "qual"
      }

      if { [regexp -nocase {II.*III} $Competition(title1)] ||
	   [regexp -nocase {II.*III} $Competition(title2)] ||
	   [regexp -nocase {II.*III} $Competition(title3)] ||
	   [regexp -nocase {II.*III} $Competition(title4)] } {
	set Competition(isQualifier) d23
      }

      if { [regexp -nocase {2.*3} $Competition(title1)] ||
	   [regexp -nocase {2.*3} $Competition(title2)] ||
	   [regexp -nocase {2.*3} $Competition(title3)] ||
	   [regexp -nocase {2.*3} $Competition(title4)] } {
	set Competition(isQualifier) d23
      }
    }


    # default to youth (because there are lots of them)
    # you can only get class change at junior, senior and veteran
    set Competition(isYouth) 1
    if { $Competition(category) == "junior" ||
         $Competition(category) == "senior" ||
         $Competition(category) == "veteran" } {
	set Competition(isYouth) {} 
    }
}

# End of fencing_usfa.tcl
