# fencing_util.tcl - utililty functions
#
# Copyright 2006, Tony Aiuto
#
# Author: Tony Aiuto, tony.aiuto@gmail.com
#


#############################################################
#
# utility routines
#


#
# Dereference a variable
#

proc deref { var } {
        upvar $var x
        return $x
}



#
# Open a file as if it was a case insensitive file system
#
proc OpenCaseless { file mode } {

	if { [file exists $file] } {
		return [open $file $mode]
	}

	set gname ""
	for { set i 0 } { $i < [string length $file]} {incr i} {
		set s [string tolower [string index $file $i]]
		if { [string first $s "abcdefghijklmnopqrstuvwxyz"] >= 0} {
			append gname {[} $s [string toupper $s] {]}
		} else {
			append gname $s
		}
	} 
	catch {
		set files [glob $gname]
		if { [llength $files] > 0 } {
			set file [lindex $files 0]
		}
	} err
	# if { $err == "" } { puts "$file -> $actualFile" }
	# puts "file -> $file"
	return [open "$file" $mode]
}


#
# convert a name to a decent file name
#
proc FolderToFileName { foldername } {
	regsub -all {/\.$} $foldername {} foldername
	regsub -all {/$} $foldername {} foldername
	regsub -all {^../} $foldername {} foldername
	regsub -all {;} $foldername {} foldername
	regsub -all {\'} $foldername {} foldername
	regsub -all {"} $foldername {} foldername
	regsub -all {  *} $foldername {_} foldername
	return $foldername
}



proc isVowel { s t f} {
    if { [string first [string tolower $s] "aeiou"] >= 0 } {
       return $t
    }
    return $f
}


proc listget { list tag _ret } {
    upvar $_ret ret
    for { set i 0 } { $i < [llength $list] } { incr i } {
	if { [lrange $list $i $i] == $tag } {
	    incr i
	    set ret [lrange $list $i $i]
	    return 1
	}
    }
    return 0
}

#
# Find the an value by name in a list of the form
#	{ { name1 value1 } {name2 value2} ... }
#

proc lfind { list tag } {
  foreach e $list {
    if { [lindex $e 0] == $tag } {
      return [lindex $e 1]
    }
  }
  return ""
}



#
# end utility routines
#
#############################################################
