# print_PS.tcl - postscript printing routines
#
# Copyright 2006, Tony Aiuto
#
# Author: Tony Aiuto, tony.aiuto@gmail.com
#


###############################################
#
# Some routines to deal with Postscript printing

# If this was not set, use a default
if { ! [info exists PS_extension] } {
	set PS_extension "ps"
}


set _print_PS_page 0

###############################################


proc lineBreak_PS { out } {
  puts $out " linedown"
}

proc startPage_PS { out } {
  global _print_PS_page
  incr _print_PS_page
  puts $out "%%Page: $_print_PS_page $_print_PS_page"
  puts $out {%%BeginPageSetup}

  # TODO - make the right thing happen
  puts $out {%%PageOrientation: Portrait}
  puts $out {.1 .1 scale}

  # puts $out {%%PageOrientation: Landscape}
  # puts $out { 10 780 translate -90 rotate .1 .1 scale}

  puts $out {%%EndPageSetup}
  puts $out {hpos vpos moveto}
}

proc endPage_PS { out } {
  puts $out { showpage}
  puts $out {%%PageTrailer}
}

proc pageBreak_PS { out } {
   endPage_PS $out
   startPage_PS $out
}

proc PrintHeader_PS { out title } {
  puts $out {%% DocumentInfo - THIS IS NOT DSC compliant}
  puts $out {%% http-equiv=Content-Language content=en-us}
  puts $out {%% content="engarde2html" name=GENERATOR}
  puts $out {%% content="Tony Aiuto" name=AUTHOR}
  puts $out {%% content="http://www.liusfa.org/tools" name=GENERATOR_URL}
  puts $out "%% Title: $title"
}



proc BodyStart_PS { out } {
  puts $out {% <BodyStart_PS/>}
}

proc BodyEnd_PS { out } {
  puts $out {% <BodyEnd_PS>}
  puts $out {%%Trailer}
  puts $out {% </BodyEnd_PS>}
}

proc DocumentStart_PS { out } {
  global VERSION

  puts $out {%!PS-Adobe-2.0}
puts $out "%%Creator: engarde2html $VERSION"
puts $out {%%LanguageLevel: 2
%%Pages: (atend)
%%CreatorAuthor: Tony Aiuto
%%CreatorURL: http://www.liusfa.org/tools
%%EndComments
%%BeginProlog
%!PS

% sizes in decipoints
/inch 720 def
/fontSize 72 def
/leading 80


/left_margin inch .75 mul def
/right_margin inch .75 mul def
/top_margin inch .75 mul def
/bottom_margin inch .75 mul def


/vpos inch 11 mul top_margin sub def
/hpos left_margin def


% Mount Greenwich typefaces
/fs /Symbol findfont 1 scalefont def

% mv - move to,	x y mv -> -
/mv { moveto } def

% nl - move down a line
/nl { /vpos vpos leading sub def
      /hpos left_margin def
      hpos vpos moveto
} def


/setFontSize {
	/fontSize exch def
	/leading fontSize 1.2 mul def
} def


% estringwidth - find a string width, a hack to work around the euro character
/estringwidth {				% string - wx wy
	 /swx 0 def /swy 0 def		% counters for individual char widths
	{
		dup 8#200 eq
		{ 			% c
			pop				% -
			currentfont /FontName get	% fontname
			dup euroFontMap exch known	% fontname ?inEuroMap
			{ euroFontMap exch get } 
			{ pop /EuroMono-Regular }
			ifelse			% euroFontName
			findfont		% efDict
			% find width of bounding box	%
			/FontBBox get 			% bbox
			dup 0 get exch 2 get add 	% bboxwid

	%%		% get x scale from euro font def and invert it
	%%		% use that for the font scale
	%%		exch /FontMatrix get 0 get	% bboxwid x-scale
	%%		% 1 exch div			% bboxwid scale'

			currentfont /FontMatrix get 0 get

			mul				% wx
			0				% wx wy
		}
		{ 1 string dup 0	% c str str 0
		  4 -1 roll		% str str 0 c
		  put			% str
		  stringwidth }
		ifelse
		swy add /swy exch def		% wx wy - wx
		swx add /swx exch def		% wx -
	} forall
	% swx 20 string cvs show (,) show swy 20 string cvs show
	swx swy
} def

% sl - set left,	string x y sl -> -
/sl { moveto show } def

% sr - set right,	string x y sr -> -
/sr { moveto dup estringwidth pop neg 0 rmoveto show } def

% sc - set center,	string x y sc -> -
/sc { moveto dup estringwidth pop 2 div neg 0 rmoveto show } def

% rl - insert rule	w h rl -> -
% /rl { rlineto stroke } def
% /rl { 10 div setlinewidth 0 rlineto stroke } def
/rl { setlinewidth 0 rlineto stroke } def

% pc - put non-ascii character
% code pc -> -
/char 1 string def
/pc { char 0 3 -1 roll put char show } def


% This section adds some characters to the Std. Encoding of all of the new
%  style fonts.  If at some point support is added for additional fonts 
%  make sure to add an encoding for it.  The new characters are:
%	A" O" U" a" o" u" (the '"' represents an umlaut above the letter
%  all of the characters  are in their ISO-8859 Latin-1 position except
%  A", which is put in octal 300 since it's ISO code was already occupied.
% A lot of this stuff is taken vebatim from the PostScript Cookbook
%
%					PWS 10/31/96
%
% It also adds the Euro symbol to any font reencoded this way
% tony 1999/05/12


% Lookup up proper Euro font and scale to current font size
/euroDraw {
	currentfont /FontName get	% fontname
	dup euroFontMap exch known	% fontname ?_is_in_euroFontMap
		{ euroFontMap exch get } 
		{ pop /EuroMono-Regular }
		ifelse			% euroFontName
		findfont		% efDict
		dup			% efDict efDict
		% get x scale from euro font def and invert it
		% use that for the font scale
		dup /FontMatrix get 0 get	% efDict efDict x-scale
		1 exch div scalefont setfont	% efDict
		% substitute for (E) stringwidth
		/FontBBox get dup 0 get exch 2 get add 	% bboxwidth
		0 setcharwidth
		0 0 moveto /Euro glyphshow
} def


% This map selects the proper Euro symbol typeface for the current typeface
% The code defaults to /EuroMono-Regular for faces not named in the map

/euroFontMap 10 dict def
euroFontMap begin
/Univers-Bold /EuroSans-Bold def
/Univers-BlackOblique /EuroSans-BoldItalic def
/Univers-Black /EuroSans-Bold def
/Univers-Light /EuroSans-Regular def
/NewBaskerville-Roman /EuroSerif-Regular def
/NewBaskerville-Italic /EuroSerif-Italic def
/NewBaskerville-Bold /EuroSerif-Bold def
end


% copy and reencode the font dictionary
/reencsmalldict 12 dict def
/ReEncodeSmall
 { reencsmalldict begin
   /newcodesandnames exch def
   /newfontname exch def
   /basefontname exch def

   /basefontdict basefontname findfont def
   /newfont basefontdict maxlength 8 add dict def

   newfont begin
   basefontdict
    { exch dup /FID ne				%% skip FID element
       { dup /Encoding eq			%% copy Encoding
          { exch dup length array copy		% /Encoding edict'
	     def 				%% save into newfont
             % 3 1 roll put			%% save into newfont
	  }
	  { dup /CharStrings eq			%% copy CharStrings
						% csdict /CharStrings
		{ exch dup 			% /CharStrings csdict csdict
		  maxlength 2 add dict copy	% /CharStrings csdict'
		  dup /euro /euroDraw load put 	%% insert Euro entry
						% /CharStrings csdict'
		  % newfont 3 1 roll put	%% save back into newfont
		  def				%% save back into newfont
		}
	    	{ exch def }			%% save into newfont
	    	% { exch newfont 3 1 roll put }	%% save into newfont
		ifelse
	  }
          ifelse
       }
       { pop pop }				%% pop the FID entry
       ifelse
    } forall
   /FontName newfontname def
   % /FontType 3 def
   newcodesandnames aload pop
   newcodesandnames length 2 idiv
    { Encoding 3 1 roll put }
    repeat
   end

   % newfont /CharStrings get /euro /euroDraw load put 

   newfontname newfont definefont pop
   end
 } def

/germanvec [
 8#226 /endash
 8#227 /emdash
 8#200 /euro
 8#300 /Agrave
 8#301 /Aacute
 8#302 /Acircumflex
 8#303 /Atilde
 8#304 /Adieresis
 8#310 /Egrave
 8#311 /Eacute
 8#326 /Odieresis
 8#334 /Udieresis
 8#337 /germandbls
 8#340 /agrave
 8#341 /aacute
 8#344 /adieresis
 8#350 /egrave
 8#351 /eacute
 8#366 /odieresis
 8#374 /udieresis
 ] def

% end of font recoding

% End of startup


% created by dps (version 2.0)
/f1 /Univers-Bold findfont 1 scalefont def
/f2 /Univers-BlackOblique findfont 1 scalefont def
/f3 /Univers-Black findfont 1 scalefont def
/f4 /NewBaskerville-Roman findfont 1 scalefont def
/f5 /NewBaskerville-Italic findfont 1 scalefont def
/f6 /NewBaskerville-Bold findfont 1 scalefont def
/f7 /Univers-Light findfont 1 scalefont def
/f8 /Univers-LightOblique findfont 1 scalefont def
/f10 /Univers findfont 1 scalefont def
/f11 /Univers-Oblique findfont 1 scalefont def
/f13 /Univers-Bold findfont 1 scalefont def
/f14 /Univers-BoldOblique findfont 1 scalefont def



%%EndProlog
}

}
proc DocumentEnd_PS { out } {
  puts $out {%%EOF}
  puts $out {}
}

# end routines to deal with Postscript printing
#
###############################################
