# print_html.tcl - utility functions for HTML printing
#
# Copyright 2006, Tony Aiuto
#
# Author: Tony Aiuto, tony.aiuto@gmail.com
#


# If this was not set, use a default
if { ! [info exists HTML_extension] } {
	set HTML_extension "html"
}


###############################################
#
# Some routines to deal with HTML printing
#

global CSS_FILE_NAME
if { ! [info exists CSS_FILE_NAME] || $CSS_FILE_NAME == "" } {
	set CSS_FILE_NAME "styles.css"
}
	

proc lineBreak_HTML { out } {
  puts -nonewline $out "<br/>"
}

proc PrintHeader_HTML { out title } {
  global progpath
  global CSS_FILE_NAME INCLUDE_CSS_FILE

  puts $out {<head>}
  if { [info procs local_HTML_head_begin] != "" } {
	local_HTML_head_begin $out
  }
  puts $out {<META http-equiv=Content-Language content=en-us>}
  puts $out {<META content="engarde2html" name=GENERATOR>}
  puts $out {<META content="Tony Aiuto" name=GENERATOR_AUTHOR>}
  puts $out {<META content="Tony.Aiuto@gmail.com" name=GENERATOR_AUTHOR_EMAIL>}
  puts $out {<META content="http://www.liusfa.org/tools" name=GENERATOR_URL>}
  puts $out {<META http-equiv=Content-Type content="text/html; charset=iso-8859-1">}
  puts $out "<title>$title</title>"
  if { ! [info exists INCLUDE_CSS_FILE] || $INCLUDE_CSS_FILE == 0 } {
    puts $out "<link rel=\"stylesheet\" type=\"text/css\" href=\"$CSS_FILE_NAME\">"
  }
  puts $out {<style>}
  puts $out {.gridrow { height:25; }}
  puts $out {.gridcell { width:25; text-align:center; }}
  puts $out {.gridblack { width:25; background:black; }}

  catch {
   if { [info exists INCLUDE_CSS_FILE] && $INCLUDE_CSS_FILE != 0 } {
    set fid [open [file join $progpath $CSS_FILE_NAME] "r"]
    set style [read $fid]
    close $fid
    puts $out $style
   }
  }
  puts $out {</style>}

  if { [info procs local_HTML_head_end] != "" } {
	local_HTML_head_end $out
  }
  puts $out {</head>}
}

proc BodyStart_HTML { out } {
  global HTML_extension
  puts $out {<body>}

  if { [info procs local_HTML_body_begin] != "" } {
	local_HTML_body_begin $out
  }
}


proc BodyEnd_HTML { out } {
  puts $out {<a name="end"/>}
  if { [info procs local_HTML_body_end] != "" } {
	local_HTML_body_end $out
  }
  puts $out {</body>}
}

proc DocumentStart_HTML { out } {
  puts $out {<html>}
  if { [info procs local_HTML_document_begin] != "" } {
	local_HTML_document_begin $out
  }
}
proc DocumentEnd_HTML { out } {
  if { [info procs local_HTML_document_end] != "" } {
	local_HTML_document_begin $out
  }
  puts $out {</html>}
}


proc HTML_table_cell { out text style } {
	if { $text == "" } {
		set text "&nbsp;"
	}
	if { $style == "" } {
		puts -nonewline $out "<td>$text</td>"
	} else {
		puts -nonewline $out "<td class=\"$style\">$text</td>"
	}
}


# end routines to deal with HTML printing
#
###############################################


###############################################
#
# text fallbacks
#

proc lineBreak_ { out } { puts $out }

proc lineBreak_text { out } { puts $out "" }

proc pageBreak_text { out } { puts -nonewline "\f" }

