# scoresheets.tcl - print DE scoresheets
#
# Author: Tony Aiuto, tony.aiuto@gmail.com
#
# Copyright 2006, Tony Aiuto
#


#######################################################
#
# routines for printing DE score sheets
#
#

proc desheets { PrintStyle out } {
  global tableSize
  global suite_tableaux

  foreach round [list a b c d] {
    if { [info exists tableSize($round)] } {
      array set rdata $suite_tableaux([string toupper $round])

      desheets_PrintRound $PrintStyle $out $round
    }
  }
}


#
# This prints the scoresheets for a round of DEs
#
#

proc desheets_PrintRound { PrintStyle out round } {
  global Competition Fencer
  global table
  global tableSize

  # puts "T size = $tableSize($round)"

  set roundName(1) "x"
  set roundName(2) "A"
  set roundName(4) "B"
  set roundName(8) "C"
  set roundName(16) "D"
  set roundName(32) "E"
  set roundName(64) "F"

  set maxrow [expr $tableSize($round) * 2]

    # The winners and losers from this round fill a certain set of
    # slots in the final rankings.  For the A round, that is
    # the normal positions.  For a B round, we are back filling
    # slots.   A B2 round should be for 3rd place, so I think
    # the right thing is ...
    # for Bn round, the slots are n+1...n+n
    set roundBase 1
    if { $round == "a" } {
	set roundBase 1
    } elseif { $round == "b" } {
    	set roundBase 3
    } elseif { $round == "c" } {
	# wild guess 2^2+1, based on a = 2^0 + 1, b=2^1+1
        set roundBase 5
    }

  #
  # roll down the tables from largest to smallest and get the match
  # data for each.    Transpose that into a vector (by column) of
  # who where the fencers and the # of points they got
  set col 0
  set nPrinted 0
  for { set tsize $tableSize($round) } { $tsize > 1 } { set tsize [expr $tsize / 2]} {

    # puts $table($round$tsize)
    if { [ info exists table($round$tsize) ] } {
      set matches [lfind $table($round$tsize) les_matches]

      # puts $out "<hr/>$round Round of Direct Eliminations"
      set bout_number 0
      foreach m $matches {
        incr bout_number
    	set match [lfind $m match]
	# break out the match data
	set fencer1 [lindex $match 0]
	set fencer2 [lindex $match 1]
	if { $fencer1 == "nobody" } continue
	if { $fencer1 == "" } continue
	if { $fencer2 == "nobody" } continue
	if { $fencer2 == "" } continue

	set winner  [lindex $match 4]
	if { $winner != "" } continue

	if { $nPrinted == 3 } {
		pageBreak_$PrintStyle $out
		set nPrinted 0
	}
	desheet_print_match_$PrintStyle $out $roundName($tsize) $bout_number $match
	incr nPrinted
      }
    }
  }
}

set PageWidth 900

proc printPenaltyLine { out } {
	global PageWidth
	puts $out "<table width=\"$PageWidth\" class=\"ScoreSheet\" cellspacing=\"0\">"
	puts $out "<tr>"
	puts $out     "<th colspan=\"34\">"
	puts $out "&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;"
	puts $out "&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;"
	puts $out "&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;"
	puts $out "&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;"
	puts $out "&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;"
	puts $out "&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;"
	puts $out "Yellow Card&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;"
	puts $out "Red Card&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;"
	puts $out "Grp3 Red Card&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;"
	puts $out "Black Card&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;"
	puts $out "</th>"
	puts $out "</tr>"
}

proc desheet_print_match_HTML { out round boutnumber match } {
	global PageWidth
	global Competition
	global Fencer

	# break out the match data
	set fencer1 [lindex $match 0]
	set fencer2 [lindex $match 1]

	if { $fencer1 == "nobody" } return
	if { $fencer1 == "" } return
	if { $fencer2 == "nobody" } return
	if { $fencer2 == "" } return

	set points1 [lindex $match 2]
	set points2 [lindex $match 3]
	set winner  [lindex $match 4]
	set seed1 [lindex $match 5]
	set seed2 [lindex $match 6]
	lappend fl $fencer1 $fencer2
	lappend sl $points1 $points2
	lappend seeds $seed1 $seed2

	# puts $out "<br/> DE $fencer1 $fencer2"

	puts $out "<br/>"
	puts $out "<hr>"
	puts $out "<br/>"

	puts $out "<table width=\"$PageWidth\" class=\"ScoreSheet\" cellspacing=\"0\">"
	puts $out "<tr><th width=\"500\">Tournament: $Competition(title1)</th>"
	puts $out     "<th class=SS>Competition:</th>"
	puts $out "</tr>"
	puts $out "<tr><th width=\"500\">Bout: &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp; $round $boutnumber</th>"
	puts $out     "<th class=SS>Strip:</th>"
	puts $out "</tr>"
	puts $out {</table>}

	printPenaltyLine $out


	puts $out "<tr>"
	puts $out "<th>Seed</th>"
	puts $out "<th width=\"200\">Name</th>"
	foreach x { 1 2 3 } {
		puts -nonewline $out "<th xclass=\"LeftBold\">1</th>"
		foreach n { 2 3 4 5 6 7 8 9 } {
			puts -nonewline $out "<th>$n</th>"
		}
		puts $out "<th class=\"LeftBold\">V</th>"
	}
	puts $out "<th class=\"LeftBold\">V/D</th>"
	puts $out "</tr>"


	puts $out "<tr>"
	puts $out "<th>$seed1</th>"
	puts $out "<th>[FencerName $fencer1]</th>"
	foreach x { 1 2 3 } {
		puts -nonewline $out "<td xclass=\"LeftBold\">&nbsp;</td>"
		foreach n { 2 3 4 5 6 7 8 9 } {
			puts -nonewline $out "<td>&nbsp;</td>"
		}
		puts $out "<th class=\"LeftBold\">&nbsp;</th>"
	}
	puts $out "<th class=\"LeftBold\">&nbsp;</th>"
	puts $out "</tr>"

	puts $out "<tr>"
	puts $out "<th>$seed2</th>"
	puts $out "<th>[FencerName $fencer2]</th>"
	foreach x { 1 2 3 } {
		puts -nonewline $out "<td xclass=\"LeftBold\">&nbsp;</td>"
		foreach n { 2 3 4 5 6 7 8 9 } {
			puts -nonewline $out "<td>&nbsp;</td>"
		}
		puts $out "<th class=\"LeftBold\">&nbsp;</th>"
	}
	puts $out "<th class=\"LeftBold\">&nbsp;</th>"
	puts $out "</tr>"

	printPenaltyLine $out
	puts $out "<tr><th width=\"500\">Refereee:</th>"
	puts $out     "<th>ScoreKeeper:</th>"
	puts $out "</tr>"

	puts $out {</table>}
	
}

#
# End of routines for DE scoresheet printing HTML
#
#######################################################


#######################################################
#
# End of routines for DE scoresheet printing Postscript
#

proc desheets_PS { out } {
  global tableSize
  global suite_tableaux

  foreach round [list a b c d] {
    if { [info exists tableSize($round)] } {
      array set rdata $suite_tableaux([string toupper $round])

      if { $round != "a" } {
        puts $out "<p class=\"subsection\">$rdata(nom_tableaux)</p>"
      }
      desheets_PrintRound_PS $out $round
    }
  }
}


#
# This prints the scoresheets for a round of DEs
#
#


proc desheets_PrintRound_PS { out round } {
  global Competition Fencer
  global table
  global tableSize

  # puts "T size = $tableSize($round)"

  set roundName(1) "x"
  set roundName(2) "A"
  set roundName(4) "B"
  set roundName(8) "C"
  set roundName(16) "D"
  set roundName(32) "E"
  set roundName(64) "F"

  set maxrow [expr $tableSize($round) * 2]

    # The winners and losers from this round fill a certain set of
    # slots in the final rankings.  For the A round, that is
    # the normal positions.  For a B round, we are back filling
    # slots.   A B2 round should be for 3rd place, so I think
    # the right thing is ...
    # for Bn round, the slots are n+1...n+n
    set roundBase 1
    if { $round == "a" } {
	set roundBase 1
    } elseif { $round == "b" } {
    	set roundBase 3
    } elseif { $round == "c" } {
	# wild guess 2^2+1, based on a = 2^0 + 1, b=2^1+1
        set roundBase 5
    }

  #
  # roll down the tables from largest to smallest and get the match
  # data for each.    Transpose that into a vector (by column) of
  # who where the fencers and the # of points they got
  set col 0
  set nPrinted 0
  for { set tsize $tableSize($round) } { $tsize > 1 } { set tsize [expr $tsize / 2]} {

    # puts $table($round$tsize)
    if { [ info exists table($round$tsize) ] } {
      set matches [lfind $table($round$tsize) les_matches]

      # puts $out "<hr/>$round Round of Direct Eliminations"
      set bout_number 0
      foreach m $matches {
        incr bout_number
    	set match [lfind $m match]
	# break out the match data
	set fencer1 [lindex $match 0]
	set fencer2 [lindex $match 1]
	if { $fencer1 == "nobody" } continue
	if { $fencer1 == "" } continue
	if { $fencer2 == "nobody" } continue
	if { $fencer2 == "" } continue

	if { $nPrinted == 3 } {
		puts $out "<p class=\"breakhere\"></p>"
		set nPrinted 0
	}
	desheet_print_match_PS $out $roundName($tsize) $bout_number $match
	incr nPrinted
      }
    }
  }
}

set PageWidth 900

proc printPenaltyLine { out } {
	global PageWidth
	puts $out "<table width=\"$PageWidth\" class=\"ScoreSheet\" cellspacing=\"0\">"
	puts $out "<tr>"
	puts $out     "<th colspan=\"40\">"
	puts $out "&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;"
	puts $out "&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;"
	puts $out "&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;"
	puts $out "&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;"
	puts $out "&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;"
	puts $out "&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;"
	puts $out "Yellow Card&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;"
	puts $out "Red Card&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;"
	puts $out "Grp3 Red Card&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;"
	puts $out "Black Card&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;"
	puts $out "</th>"
	puts $out "</tr>"
}

proc desheet_print_match_PS { out round boutnumber match } {
	global PageWidth
	global Competition
	global Fencer

	# break out the match data
	set fencer1 [lindex $match 0]
	set fencer2 [lindex $match 1]

	if { $fencer1 == "nobody" } return
	if { $fencer1 == "" } return
	if { $fencer2 == "nobody" } return
	if { $fencer2 == "" } return

	set points1 [lindex $match 2]
	set points2 [lindex $match 3]
	set winner  [lindex $match 4]
	set seed1 [lindex $match 5]
	set seed2 [lindex $match 6]
	lappend fl $fencer1 $fencer2
	lappend sl $points1 $points2
	lappend seeds $seed1 $seed2

	# puts $out "<br/> DE $fencer1 $fencer2"

	puts $out "<br/>"
	puts $out "<hr>"
	puts $out "<br/>"

	puts $out "<table width=\"$PageWidth\" class=\"ScoreSheet\" cellspacing=\"0\">"
	puts $out "<tr><th width=\"500\">Tournament: $Competition(title1)</th>"
	puts $out     "<th class=SS>Competition:</th>"
	puts $out "</tr>"
	puts $out "<tr><th width=\"500\">PSBout: &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp; $round $boutnumber</th>"
	puts $out     "<th class=SS>Strip:</th>"
	puts $out "</tr>"
	puts $out {</table>}

	printPenaltyLine $out


	puts $out "<tr>"
	puts $out "<th>Seed</th>"
	puts $out "<th width=\"200\">Name</th>"
	foreach x { 1 2 3 } {
		puts $out "<th xclass=\"LeftBold\">1</th>"
		foreach n { 2 3 4 5 6 7 8 9 } {
			puts $out "<th>$n</th>"
		}
		puts $out "<th class=\"LeftBold\">V</th>"
	}
	puts $out "<th class=\"LeftBold\">V/D</th>"
	puts $out "</tr>"


	puts $out "<tr>"
	puts $out "<th>$seed1</th>"
	puts $out "<th>$fencer1</th>"
	puts $out "<th>[FencerName $fencer1]</th>"
	foreach x { 1 2 3 } {
		puts $out "<td xclass=\"LeftBold\">&nbsp;</td>"
		foreach n { 2 3 4 5 6 7 8 9 } {
			puts $out "<td>&nbsp;</td>"
		}
		puts $out "<th class=\"LeftBold\">&nbsp;</th>"
	}
	puts $out "<th class=\"LeftBold\">&nbsp;</th>"
	puts $out "</tr>"

	puts $out "<tr>"
	puts $out "<th>$seed2</th>"
	puts $out "<th>$fencer2</th>"
	puts $out "<th>[FencerName $fencer2]</th>"
	foreach x { 1 2 3 } {
		puts $out "<td xclass=\"LeftBold\">&nbsp;</td>"
		foreach n { 2 3 4 5 6 7 8 9 } {
			puts $out "<td>&nbsp;</td>"
		}
		puts $out "<th class=\"LeftBold\">&nbsp;</th>"
	}
	puts $out "<th class=\"LeftBold\">&nbsp;</th>"
	puts $out "</tr>"

	printPenaltyLine $out
	puts $out "<tr><th width=\"500\">Refereee:</th>"
	puts $out     "<th>ScoreKeeper:</th>"
	puts $out "</tr>"

	puts $out {</table>}
	
}

#
# End of routines for DE scoresheet printing
#
#######################################################


#######################################################
#
#
# Main body for printing a scoresheet
#

proc DoSheets { out } {
    global PrintStyle Fencer Competition

    InitCompetition
    Engarde_LoadCompetition

    if { [file exists "clas_fin_poules.txt"] } {
	LoadEndOfRound "clas_fin_poules.txt" EndOfPoolsData
    }
    #
    # if we are still in the pools, stop here
    #
    if { $Competition(phase) == "pools" } {
       return
    }

    # if we finished pools, but have not started DEs
    global DEF_ma_competition
    if { ! [info exists DEF_ma_competition(tableauxactifs)] } {
       return
    }

    Print_Begin $out

    #
    # calculate seeds for DEs
    # also figure out where you would be in the printed tables
    set bouts [GenerateDEBouts $Competition(nFencers)]
    SeedToDETable $bouts seed2table
    foreach fi [lsort -integer [array names EndOfPoolsData]] {
	array set fd $EndOfPoolsData($fi)
	set FI $fd(fnumber)
	# puts $out "<br/>$fi - $fd(rank) - [FencerName $FI]"
	array set tmp $Fencer($FI)
	set tmp(seed) $fd(rank)
	set tmp(final_rank) $fd(rank)
	set tmp(tableIndex) $seed2table($fd(rank))
	set Fencer($FI) [array get tmp]
    }

    LoadAllTableaux

    desheets $PrintStyle $out
    # Tables_HTML $out

    Print_FinishUp $out
}
